@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file auth.h
  * \brief A header for the ident functions.
- * \version $Id: auth.h 7667 2016-07-20 17:09:36Z michael $
+ * \version $Id: auth.h 7954 2017-03-04 19:37:07Z michael $
  */
 
 #ifndef INCLUDED_auth_h
@@ -62,7 +62,7 @@ struct AuthRequest
 };
 
 extern void auth_init(void);
-extern void start_auth(struct Client *);
-extern void delete_auth(struct AuthRequest *);
+extern void auth_start(struct Client *);
+extern void auth_delete(struct AuthRequest *);
 extern void release_auth_client(struct AuthRequest *);
 #endif
