@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.h
  * \brief Includes channel mode related definitions and structures.
- * \version $Id: channel_mode.h 7763 2016-10-06 16:59:51Z michael $
+ * \version $Id: channel_mode.h 8045 2017-03-18 18:05:41Z michael $
  */
 
 #ifndef INCLUDED_channel_mode_h
@@ -38,9 +38,9 @@ enum { MAXMODEPARAMS = 6 };
 
 enum
 {
-  MODE_QUERY =  0,
-  MODE_ADD   =  1,
-  MODE_DEL   = -1
+  MODE_QUERY = 0,
+  MODE_DEL   = 1,
+  MODE_ADD   = 2
 };
 
 enum
@@ -90,9 +90,15 @@ enum
   MODE_NOCTRL     = 0x00000400U,  /**< Prevents users from sending messages containing control codes to the channel */
   MODE_MODREG     = 0x00000800U,  /**< Unregistered/unidentified clients cannot send text to the channel */
   MODE_NOCTCP     = 0x00001000U,  /**< Clients cannot send CTCP messages to the channel */
-  MODE_NONOTICE   = 0x00002000U   /**< Clients cannot send NOTICE to the channel */
+  MODE_NONOTICE   = 0x00002000U,  /**< Clients cannot send NOTICE to the channel */
+  MODE_HIDEBMASKS = 0x00004000U,  /**< Hides +b/+e/+I lists/changes for non-chanops everywhere */
+  MODE_EXTLIMIT   = 0x00008000U   /**< Channel can make use of the extended ban list limit */
 };
 
+#define HasCMode(x, y) ((x)->mode.mode &   (y))
+#define AddCMode(x, y) ((x)->mode.mode |=  (y))
+#define DelCMode(x, y) ((x)->mode.mode &= ~(y))
+
 /* name invisible */
 #define SecretChannel(x)        (((x)->mode.mode & MODE_SECRET))
 #define PubChannel(x)           (((x)->mode.mode & (MODE_PRIVATE | MODE_SECRET)) == 0)
@@ -112,7 +118,8 @@ struct ChModeChange
   char letter;
   const char *arg;
   const char *id;
-  int dir;
+  unsigned int dir;
+  unsigned int flags;
 };
 
 struct mode_letter
