@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id: client.h 7863 2016-11-08 20:17:03Z michael $
+ * \version $Id: client.h 7996 2017-03-14 13:17:39Z michael $
  */
 
 
@@ -454,9 +454,9 @@ extern void dead_link_on_write(struct Client *, int);
 extern void dead_link_on_read(struct Client *, int);
 extern void exit_aborted_clients(void);
 extern void free_exited_clients(void);
-extern struct Client *make_client(struct Client *);
+extern struct Client *client_make(struct Client *);
 extern struct Client *find_chasing(struct Client *, const char *);
 extern struct Client *find_person(const struct Client *, const char *);
-extern const char *get_client_name(const struct Client *, enum addr_mask_type);
+extern const char *client_get_name(const struct Client *, enum addr_mask_type);
 
 #endif /* INCLUDED_client_h */
