@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.h
  * \brief A header for the ircd startup routines.
- * \version $Id: ircd.h 7863 2016-11-08 20:17:03Z michael $
+ * \version $Id: ircd.h 7998 2017-03-14 13:50:29Z michael $
  */
 
 
@@ -76,15 +76,11 @@ struct ServerStatistics
 struct Counter
 {
   uintmax_t totalrestartcount; /* Total client count ever */
-  unsigned int myserver;      /* my servers          */
   unsigned int oper;          /* Opers               */
-  unsigned int local;         /* Local Clients       */
-  unsigned int total;         /* total clients       */
   unsigned int invisi;        /* invisible clients   */
   unsigned int max_loc;       /* MAX local clients   */
   unsigned int max_tot;       /* MAX global clients  */
   unsigned int max_loc_con;   /* MAX local connection count (clients + server) */
-  unsigned int max_loc_cli;   /* XXX This is redundant - Max local client count */
 };
 
 struct ServerState_t
