@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.h
  * \brief A header for the message sending functions.
- * \version $Id: send.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: send.h 7925 2016-12-31 13:57:24Z michael $
  */
 
 #ifndef INCLUDED_send_h
@@ -62,29 +62,28 @@ extern void sendq_unblocked(fde_t *, void *);
 extern void send_queued_write(struct Client *);
 extern void send_queued_all(void);
 extern void sendto_one(struct Client *, const char *, ...) AFP(2,3);
-extern void sendto_one_numeric(struct Client *, struct Client *, enum irc_numerics, ...);
-extern void sendto_one_notice(struct Client *, struct Client *, const char *, ...) AFP(3,4);
-extern void sendto_channel_butone(struct Client *, struct Client *,
+extern void sendto_one_numeric(struct Client *, const struct Client *, enum irc_numerics, ...);
+extern void sendto_one_notice(struct Client *, const struct Client *, const char *, ...) AFP(3,4);
+extern void sendto_channel_butone(struct Client *, const struct Client *,
                                   struct Channel *, unsigned int,
                                   const char *, ...) AFP(5,6);
 extern void sendto_common_channels_local(struct Client *, int, unsigned int, unsigned int,
                                          const char *, ...) AFP(5,6);
 extern void sendto_channel_local(const struct Client *, struct Channel *, unsigned int,
                                  unsigned int, unsigned int, const char *, ...)  AFP(6,7);
-extern void sendto_server(struct Client *,
-                          const unsigned int,
+extern void sendto_server(const struct Client *, const unsigned int,
                           const unsigned int, const char *, ...) AFP(4,5);
-extern void sendto_match_butone(struct Client *, struct Client *,
+extern void sendto_match_butone(const struct Client *, const struct Client *,
                                 const char *, int, const char *, ...) AFP(5,6);
-extern void sendto_match_servs(struct Client *, const char *, unsigned int,
+extern void sendto_match_servs(const struct Client *, const char *, unsigned int,
                                const char *, ...) AFP(4,5);
 extern void sendto_realops_flags(unsigned int, int, int,
                                  const char *, ...) AFP(4,5);
-extern void sendto_wallops_flags(unsigned int, struct Client *,
+extern void sendto_wallops_flags(unsigned int, const struct Client *,
                                  const char *, ...) AFP(3,4);
-extern void sendto_realops_flags_ratelimited(time_t *, const char *, ...) AFP(2,3);
+extern void sendto_realops_flags_ratelimited(uintmax_t *, const char *, ...) AFP(2,3);
 
-extern void sendto_anywhere(struct Client *, struct Client *,
+extern void sendto_anywhere(struct Client *, const struct Client *,
                             const char *,
                             const char *, ...) AFP(4,5);
 #endif /* INCLUDED_send_h */
