@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_die.c
  * \brief Includes required functions for processing the DIE command.
- * \version $Id: m_die.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_die.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -71,7 +71,7 @@ mo_die(struct Client *source_p, int parc, char *parv[])
   }
 
   snprintf(buf, sizeof(buf), "received DIE command from %s",
-           get_client_name(source_p, HIDE_IP));
+           client_get_name(source_p, HIDE_IP));
   server_die(buf, SERVER_SHUTDOWN);
   return 0;
 }
@@ -101,7 +101,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7996 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
