@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_message.c
  * \brief Includes required functions for processing the PRIVMSG/NOTICE command.
- * \version $Id: m_message.c 7871 2016-11-09 20:13:07Z michael $
+ * \version $Id: m_message.c 8009 2017-03-15 13:41:19Z michael $
  */
 
 #include "stdinc.h"
@@ -70,25 +70,6 @@ static struct
 static unsigned int ntargets;
 
 
-/*
-** m_privmsg
-**
-** massive cleanup
-** rev argv 6/91
-**
-**   Another massive cleanup Nov, 2000
-** (I don't think there is a single line left from 6/91. Maybe.)
-** m_privmsg and m_notice do basically the same thing.
-** in the original 2.8.2 code base, they were the same function
-** "m_message.c." When we did the great cleanup in conjuncton with bleep
-** of ircu fame, we split m_privmsg.c and m_notice.c.
-** I don't see the point of that now. It's harder to maintain, it's
-** easier to introduce bugs into one version and not the other etc.
-** Really, the penalty of an extra function call isn't that big a deal folks.
-** -db Nov 13, 2000
-**
-*/
-
 /* duplicate_ptr()
  *
  * inputs       - pointer to check
@@ -148,7 +129,7 @@ flood_attack_client(int p_or_n, struct Client *source_p, struct Client *target_p
     {
       sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
                            "Possible Flooder %s on %s target: %s",
-                           get_client_name(source_p, HIDE_IP),
+                           client_get_name(source_p, HIDE_IP),
                            source_p->servptr->name, target_p->name);
       AddFlag(target_p, FLAGS_FLOOD_NOTICED);
     }
@@ -200,7 +181,7 @@ flood_attack_channel(int p_or_n, struct Client *source_p, struct Channel *chptr)
     {
       sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
                            "Possible Flooder %s on %s target: %s",
-                           get_client_name(source_p, HIDE_IP),
+                           client_get_name(source_p, HIDE_IP),
                            source_p->servptr->name, chptr->name);
       SetFloodNoticed(chptr);
     }
@@ -683,7 +664,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7871 $",
+  .version = "$Revision: 8009 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
