@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_mode.c
  * \brief Includes required functions for processing the MODE command.
- * \version $Id: m_mode.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_mode.c 8062 2017-03-23 17:13:05Z michael $
  */
 
 #include "stdinc.h"
@@ -72,7 +72,7 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
 
   if (parc < 3)
   {
-    char buf[IRCD_BUFSIZE] = "";
+    char buf[UMODE_MAX_STR] = "";
     char *m = buf;
 
     *m++ = '+';
@@ -115,7 +115,7 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
 
           if (MyConnect(source_p))
           {
-            dlink_node *node = NULL;
+            dlink_node *node;
 
             detach_conf(source_p, CONF_OPER);
             ClrOFlag(source_p);
@@ -266,7 +266,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 8062 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
