@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 7763 2016-10-06 16:59:51Z michael $
+ * \version $Id: m_nick.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -339,7 +339,7 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *client_p = NULL;
 
-  client_p = make_client(source_p->from);
+  client_p = client_make(source_p->from);
   client_p->servptr = source_p;
   client_p->hopcount = atoi(parv[2]);
   client_p->tsinfo = strtoumax(parv[3], NULL, 10);
@@ -607,7 +607,7 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
     sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, resv->reason);
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Forbidding reserved nick %s from user %s",
-                         nick, get_client_name(source_p, HIDE_IP));
+                         nick, client_get_name(source_p, HIDE_IP));
     return 0;
   }
 
@@ -666,7 +666,7 @@ m_nick(struct Client *source_p, int parc, char *parv[])
     sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, resv->reason);
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Forbidding reserved nick %s from user %s",
-                         nick, get_client_name(source_p, HIDE_IP));
+                         nick, client_get_name(source_p, HIDE_IP));
     return 0;
   }
 
@@ -849,7 +849,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7763 $",
+  .version = "$Revision: 7996 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
