@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_part.c
  * \brief Includes required functions for processing the PART command.
- * \version $Id: m_part.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_part.c 7925 2016-12-31 13:57:24Z michael $
  */
 
 #include "stdinc.h"
@@ -70,8 +70,14 @@ m_part(struct Client *source_p, int parc, char *parv[])
 
 static struct Message part_msgtab =
 {
-  "PART", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_part, m_part, m_ignore, m_part, m_ignore }
+  .cmd = "PART",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_part,
+  .handlers[SERVER_HANDLER] = m_part,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_part
 };
 
 static void
@@ -88,10 +94,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7925 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
