@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_server.c
  * \brief Includes required functions for processing the SERVER/SID command.
- * \version $Id: m_server.c 7598 2016-06-13 18:55:15Z michael $
+ * \version $Id: m_server.c 8062 2017-03-23 17:13:05Z michael $
  */
 
 #include "stdinc.h"
@@ -113,25 +113,24 @@ server_send_tburst(struct Client *client_p, const struct Channel *chptr)
 static void
 server_send_client(struct Client *client_p, struct Client *target_p)
 {
-  dlink_node *node = NULL;
-  char ubuf[IRCD_BUFSIZE] = "";
+  dlink_node *node;
+  char buf[UMODE_MAX_STR] = "";
 
-  if (!IsClient(target_p))
-    return;
+  assert(IsClient(target_p));
 
-  send_umode(target_p, 0, 0, ubuf);
+  send_umode(target_p, 0, 0, buf);
 
-  if (ubuf[0] == '\0')
+  if (buf[0] == '\0')
   {
-    ubuf[0] = '+';
-    ubuf[1] = '\0';
+    buf[0] = '+';
+    buf[1] = '\0';
   }
 
   sendto_one(client_p, ":%s UID %s %u %ju %s %s %s %s %s %s :%s",
              target_p->servptr->id,
              target_p->name, target_p->hopcount + 1,
              target_p->tsinfo,
-             ubuf, target_p->username, target_p->host,
+             buf, target_p->username, target_p->host,
              target_p->sockhost, target_p->id,
              target_p->account, target_p->info);
 
@@ -145,7 +144,7 @@ server_send_client(struct Client *client_p, struct Client *target_p)
   DLINK_FOREACH(node, target_p->svstags.head)
   {
     const struct ServicesTag *svstag = node->data;
-    char *m = ubuf;
+    char *m = buf;
 
     for (const struct user_modes *tab = umode_tab; tab->c; ++tab)
       if (svstag->umodes & tab->flag)
@@ -153,7 +152,7 @@ server_send_client(struct Client *client_p, struct Client *target_p)
     *m = '\0';
 
     sendto_one(client_p, ":%s SVSTAG %s %ju %u +%s :%s", me.id, target_p->id,
-               target_p->tsinfo, svstag->numeric, ubuf, svstag->tag);
+               target_p->tsinfo, svstag->numeric, buf, svstag->tag);
   }
 }
 
@@ -210,10 +209,10 @@ server_estab(struct Client *client_p)
     /* This shouldn't happen, better tell the ops... -A1kmm */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Warning: lost connect{} block for %s",
-                         get_client_name(client_p, SHOW_IP));
+                         client_get_name(client_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Warning: lost connect{} block for %s",
-                         get_client_name(client_p, MASK_IP));
+                         client_get_name(client_p, MASK_IP));
     exit_client(client_p, "Lost connect{} block!");
     return;
   }
@@ -243,7 +242,7 @@ server_estab(struct Client *client_p)
 
   /* *WARNING*
   **    In the following code in place of plain server's
-  **    name we send what is returned by get_client_name
+  **    name we send what is returned by client_get_name
   **    which may add the "sockhost" after the name. It's
   **    *very* *important* that there is a SPACE between
   **    the name and sockhost (if present). The receiving
@@ -259,18 +258,19 @@ server_estab(struct Client *client_p)
 
   SetServer(client_p);
 
-  /* Some day, all these lists will be consolidated *sigh* */
   dlinkAdd(client_p, &client_p->lnode, &me.serv->server_list);
 
   assert(dlinkFind(&unknown_list, client_p));
-
   dlink_move_node(&client_p->connection->lclient_node,
                   &unknown_list, &local_server_list);
 
-  Count.myserver++;
+  dlinkAdd(client_p, &client_p->node, &global_server_list);
+
+  if ((dlink_list_length(&local_client_list) +
+       dlink_list_length(&local_server_list)) > Count.max_loc_con)
+    Count.max_loc_con = dlink_list_length(&local_client_list) +
+                        dlink_list_length(&local_server_list);
 
-  dlinkAdd(client_p, &client_p->node, &global_client_list);
-  dlinkAdd(client_p, make_dlink_node(), &global_server_list);
   hash_add_client(client_p);
   hash_add_id(client_p);
 
@@ -289,16 +289,16 @@ server_estab(struct Client *client_p)
     /* Show the real host/IP to admins */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link with %s established: [TLS: %s] (Capabilities: %s)",
-                         get_client_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd.ssl),
+                         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd.ssl),
                          get_capabilities(client_p));
 
     /* Now show the masked hostname/IP to opers */
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link with %s established: [TLS: %s] (Capabilities: %s)",
-                         get_client_name(client_p, MASK_IP), tls_get_cipher(&client_p->connection->fd.ssl),
+                         client_get_name(client_p, MASK_IP), tls_get_cipher(&client_p->connection->fd.ssl),
                          get_capabilities(client_p));
     ilog(LOG_TYPE_IRCD, "Link with %s established: [TLS: %s] (Capabilities: %s)",
-         get_client_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd.ssl),
+         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd.ssl),
          get_capabilities(client_p));
   }
   else
@@ -306,13 +306,13 @@ server_estab(struct Client *client_p)
     /* Show the real host/IP to admins */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link with %s established: (Capabilities: %s)",
-                         get_client_name(client_p, SHOW_IP), get_capabilities(client_p));
+                         client_get_name(client_p, SHOW_IP), get_capabilities(client_p));
     /* Now show the masked hostname/IP to opers */
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link with %s established: (Capabilities: %s)",
-                         get_client_name(client_p, MASK_IP), get_capabilities(client_p));
+                         client_get_name(client_p, MASK_IP), get_capabilities(client_p));
     ilog(LOG_TYPE_IRCD, "Link with %s established: (Capabilities: %s)",
-         get_client_name(client_p, SHOW_IP), get_capabilities(client_p));
+         client_get_name(client_p, SHOW_IP), get_capabilities(client_p));
   }
 
   fd_note(&client_p->connection->fd, "Server: %s", client_p->name);
@@ -390,6 +390,69 @@ server_set_gecos(struct Client *client_p, const char *info)
     strlcpy(client_p->info, "(Unknown Location)", sizeof(client_p->info));
 }
 
+static int
+server_check(const char *name, struct Client *client_p)
+{
+  dlink_node *node = NULL;
+  struct MaskItem *server_conf = NULL;
+  int error = -1;
+
+  assert(client_p);
+
+  /* Loop through looking for all possible connect items that might work */
+  DLINK_FOREACH(node, connect_items.head)
+  {
+    struct MaskItem *conf = node->data;
+
+    if (irccmp(name, conf->name))
+      continue;
+
+    error = -3;
+
+    if (!irccmp(conf->host, client_p->host) ||
+        !irccmp(conf->host, client_p->sockhost))
+    {
+      error = -2;
+
+      if (!match_conf_password(client_p->connection->password, conf))
+        return -2;
+
+      if (!EmptyString(conf->certfp))
+        if (EmptyString(client_p->certfp) || strcasecmp(client_p->certfp, conf->certfp))
+          return -4;
+
+      server_conf = conf;
+    }
+  }
+
+  if (server_conf == NULL)
+    return error;
+
+  attach_conf(client_p, server_conf);
+
+  switch (server_conf->aftype)
+  {
+    case AF_INET6:
+    {
+      const struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)&server_conf->addr;
+
+      if (IN6_IS_ADDR_UNSPECIFIED(&v6->sin6_addr))
+        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
+      break;
+    }
+    case AF_INET:
+    {
+      const struct sockaddr_in *v4 = (struct sockaddr_in *)&server_conf->addr;
+
+      if (v4->sin_addr.s_addr == INADDR_NONE)
+        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
+      break;
+    }
+  }
+
+  return 0;
+}
+
 /* mr_server()
  *  parv[0] = command
  *  parv[1] = servername
@@ -421,10 +484,10 @@ mr_server(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
           "Unauthorized server connection attempt from %s: Bogus server name "
-          "for server %s", get_client_name(source_p, SHOW_IP), name);
+          "for server %s", client_get_name(source_p, SHOW_IP), name);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
           "Unauthorized server connection attempt from %s: Bogus server name "
-          "for server %s", get_client_name(source_p, MASK_IP), name);
+          "for server %s", client_get_name(source_p, MASK_IP), name);
     exit_client(source_p, "Bogus server name");
     return 0;
   }
@@ -433,29 +496,29 @@ mr_server(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
-                         get_client_name(source_p, SHOW_IP), sid);
+                         client_get_name(source_p, SHOW_IP), sid);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
-                         get_client_name(source_p, MASK_IP), sid);
+                         client_get_name(source_p, MASK_IP), sid);
     exit_client(source_p, "Bogus server ID introduced");
     return 0;
   }
 
-  /* Now we just have to call check_server and everything should
+  /* Now we just have to call server_check() and everything should
    * be check for us... -A1kmm.
    */
-  switch (check_server(name, source_p))
+  switch (server_check(name, source_p))
   {
     case -1:
       if (ConfigGeneral.warn_no_connect_block)
       {
         sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: No entry for "
-           "servername %s", get_client_name(source_p, SHOW_IP), name);
+           "servername %s", client_get_name(source_p, SHOW_IP), name);
 
         sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: No entry for "
-           "servername %s", get_client_name(source_p, MASK_IP), name);
+           "servername %s", client_get_name(source_p, MASK_IP), name);
       }
 
       exit_client(source_p, "No connect {} block.");
@@ -466,11 +529,11 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     case -2:
       sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Bad password "
-           "for server %s", get_client_name(source_p, SHOW_IP), name);
+           "for server %s", client_get_name(source_p, SHOW_IP), name);
 
       sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Bad password "
-           "for server %s", get_client_name(source_p, MASK_IP), name);
+           "for server %s", client_get_name(source_p, MASK_IP), name);
 
       exit_client(source_p, "Invalid password.");
       return 0;
@@ -480,22 +543,22 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     case -3:
       sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid host "
-           "for server %s", get_client_name(source_p, SHOW_IP), name);
+           "for server %s", client_get_name(source_p, SHOW_IP), name);
 
       sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid host "
-           "for server %s", get_client_name(source_p, MASK_IP), name);
+           "for server %s", client_get_name(source_p, MASK_IP), name);
 
       exit_client(source_p, "Invalid host.");
       return 0;
     case -4:
       sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid certificate fingerprint "
-           "for server %s", get_client_name(source_p, SHOW_IP), name);
+           "for server %s", client_get_name(source_p, SHOW_IP), name);
 
       sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid certificate fingerprint "
-           "for server %s", get_client_name(source_p, MASK_IP), name);
+           "for server %s", client_get_name(source_p, MASK_IP), name);
 
       exit_client(source_p, "Invalid certificate fingerprint.");
       return 0;
@@ -517,10 +580,10 @@ mr_server(struct Client *source_p, int parc, char *parv[])
      */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Attempt to re-introduce server %s from %s",
-                         name, get_client_name(source_p, SHOW_IP));
+                         name, client_get_name(source_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Attempt to re-introduce server %s from %s",
-                         name, get_client_name(source_p, MASK_IP));
+                         name, client_get_name(source_p, MASK_IP));
     exit_client(source_p, "Server already exists");
     return 0;
   }
@@ -530,11 +593,11 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Attempt to re-introduce server %s SID %s from %s",
                          name, source_p->id,
-                         get_client_name(source_p, SHOW_IP));
+                         client_get_name(source_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Attempt to re-introduce server %s SID %s from %s",
                          name, source_p->id,
-                         get_client_name(source_p, MASK_IP));
+                         client_get_name(source_p, MASK_IP));
     exit_client(source_p, "Server ID already exists");
     return 0;
   }
@@ -584,12 +647,8 @@ mr_server(struct Client *source_p, int parc, char *parv[])
 static int
 ms_sid(struct Client *source_p, int parc, char *parv[])
 {
-  dlink_node *node = NULL;
   struct Client *target_p = NULL;
   struct Client *client_p = source_p->from; /* XXX */
-  const struct MaskItem *conf = NULL;
-  int hlined = 0;
-  int llined = 0;
 
   /* Just to be sure -A1kmm. */
   if (!IsServer(source_p))
@@ -605,10 +664,10 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server name %s",
-                         get_client_name(client_p, SHOW_IP), parv[1]);
+                         client_get_name(client_p, SHOW_IP), parv[1]);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced server with bogus server name %s",
-                         get_client_name(client_p, MASK_IP), parv[1]);
+                         client_get_name(client_p, MASK_IP), parv[1]);
     exit_client(client_p, "Bogus server name introduced");
     return 0;
   }
@@ -617,10 +676,10 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
-                         get_client_name(client_p, SHOW_IP), parv[3]);
+                         client_get_name(client_p, SHOW_IP), parv[3]);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
-                         get_client_name(client_p, MASK_IP), parv[3]);
+                         client_get_name(client_p, MASK_IP), parv[3]);
     exit_client(client_p, "Bogus server ID introduced");
     return 0;
   }
@@ -630,10 +689,10 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s cancelled, server ID %s already exists",
-                         get_client_name(client_p, SHOW_IP), parv[3]);
+                         client_get_name(client_p, SHOW_IP), parv[3]);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s cancelled, server ID %s already exists",
-                         get_client_name(client_p, MASK_IP), parv[3]);
+                         client_get_name(client_p, MASK_IP), parv[3]);
     exit_client(client_p, "Link cancelled, server ID already exists");
     return 0;
   }
@@ -643,10 +702,10 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s cancelled, server %s already exists",
-                         get_client_name(client_p, SHOW_IP), parv[1]);
+                         client_get_name(client_p, SHOW_IP), parv[1]);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s cancelled, server %s already exists",
-                         get_client_name(client_p, MASK_IP), parv[1]);
+                         client_get_name(client_p, MASK_IP), parv[1]);
     exit_client(client_p, "Server exists");
     return 0;
   }
@@ -659,11 +718,15 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     if (target_p != client_p)
       exit_client(target_p, "Overridden");
 
-  conf = client_p->connection->confs.head->data;
-
-  /* See if the newly found server is behind a guaranteed
+  /*
+   * See if the newly found server is behind a guaranteed
    * leaf. If so, close the link.
    */
+  dlink_node *node;
+  unsigned int hlined = 0;
+  unsigned int llined = 0;
+  const struct MaskItem *conf = client_p->connection->confs.head->data;
+
   DLINK_FOREACH(node, conf->leaf_list.head)
   {
     if (!match(node->data, parv[1]))
@@ -711,10 +774,10 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     /* OOOPs nope can't HUB */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Non-Hub link %s introduced %s.",
-                         get_client_name(client_p, SHOW_IP), parv[1]);
+                         client_get_name(client_p, SHOW_IP), parv[1]);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Non-Hub link %s introduced %s.",
-                         get_client_name(client_p, MASK_IP), parv[1]);
+                         client_get_name(client_p, MASK_IP), parv[1]);
     exit_client(source_p, "No matching hub_mask.");
     return 0;
   }
@@ -725,15 +788,15 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     /* OOOPs nope can't HUB this leaf */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced leafed server %s.",
-                         get_client_name(client_p, SHOW_IP), parv[1]);
+                         client_get_name(client_p, SHOW_IP), parv[1]);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced leafed server %s.",
-                         get_client_name(client_p, MASK_IP), parv[1]);
+                         client_get_name(client_p, MASK_IP), parv[1]);
     exit_client(client_p, "Leafed server.");
     return 0;
   }
 
-  target_p = make_client(client_p);
+  target_p = client_make(client_p);
   make_server(target_p);
   target_p->hopcount = atoi(parv[2]);
   target_p->servptr = source_p;
@@ -754,8 +817,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   if (service_find(target_p->name))
     AddFlag(target_p, FLAGS_SERVICE);
 
-  dlinkAdd(target_p, &target_p->node, &global_client_list);
-  dlinkAdd(target_p, make_dlink_node(), &global_server_list);
+  dlinkAdd(target_p, &target_p->node, &global_server_list);
   dlinkAdd(target_p, &target_p->lnode, &target_p->servptr->serv->server_list);
 
   hash_add_client(target_p);
@@ -810,7 +872,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7598 $",
+  .version = "$Revision: 8062 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
