@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2016 ircd-hybrid development team
+ *  Copyright (c) 1998-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_capab.c
  * \brief Includes required functions for processing the CAPAB command.
- * \version $Id: m_capab.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_capab.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -48,10 +48,9 @@ mr_capab(struct Client *source_p, int parc, char *parv[])
 {
   unsigned int cap = 0;
   char *p = NULL;
-  char *s = NULL;
 
-  for (s = strtok_r(parv[1], " ", &p); s;
-       s = strtok_r(NULL,    " ", &p))
+  for (const char *s = strtok_r(parv[1], " ", &p); s;
+                   s = strtok_r(NULL,    " ", &p))
     if ((cap = find_capability(s)))
       SetCapable(source_p, cap);
 
@@ -84,7 +83,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 8058 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
