@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_close.c
  * \brief Includes required functions for processing the CLOSE command.
- * \version $Id: m_close.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_close.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -61,7 +61,7 @@ mo_close(struct Client *source_p, int parc, char *parv[])
     struct Client *target_p = node->data;
 
     sendto_one_numeric(source_p, &me, RPL_CLOSING,
-                       get_client_name(target_p, SHOW_IP),
+                       client_get_name(target_p, SHOW_IP),
                        target_p->status);
 
     /*
@@ -100,7 +100,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7996 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
