@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_dline.c
  * \brief Includes required functions for processing the DLINE command.
- * \version $Id: m_dline.c 7674 2016-07-20 18:54:17Z michael $
+ * \version $Id: m_dline.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -46,7 +46,7 @@
 static void
 dline_check(const struct AddressRec *arec)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, local_client_list.head)
   {
@@ -333,7 +333,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7674 $",
+  .version = "$Revision: 8058 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
