@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2004-2016 ircd-hybrid development team
+ *  Copyright (c) 2004-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_etrace.c
  * \brief Includes required functions for processing the ETRACE command.
- * \version $Id: m_etrace.c 7909 2016-11-27 16:59:26Z michael $
+ * \version $Id: m_etrace.c 8083 2017-03-26 10:14:41Z michael $
  */
 
 #include "stdinc.h"
@@ -31,6 +31,7 @@
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
+#include "server.h"
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
@@ -85,6 +86,11 @@ do_etrace(struct Client *source_p, const char *arg)
   {
     tname = arg;
     wilds = has_wildcards(tname);
+
+    if (!match(tname, me.name))
+      do_all = 1;
+    else if (!MyClient(source_p) && !strcmp(tname, me.id))
+      do_all = 1;
   }
 
   if (!wilds && !do_all)
@@ -94,7 +100,7 @@ do_etrace(struct Client *source_p, const char *arg)
     if (target_p && MyConnect(target_p))
       report_this_status(source_p, target_p);
 
-    sendto_one_numeric(source_p, &me, RPL_TRACEEND, tname);
+    sendto_one_numeric(source_p, &me, RPL_ETRACEEND, me.name);
     return;
   }
 
@@ -106,17 +112,42 @@ do_etrace(struct Client *source_p, const char *arg)
       report_this_status(source_p, target_p);
   }
 
-  sendto_one_numeric(source_p, &me, RPL_TRACEEND, tname);
+  sendto_one_numeric(source_p, &me, RPL_ETRACEEND, me.name);
 }
 
-/* mo_etrace()
- *      parv[0] = command
- *      parv[1] = servername
+/*! \brief ETRACE command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = nick name to trace
+ *      - parv[2] = nick or server name to forward the etrace to
  */
 static int
 mo_etrace(struct Client *source_p, int parc, char *parv[])
 {
-  do_etrace(source_p, parv[1]);
+  if (parc > 2)
+    if (server_hunt(source_p, ":%s ETRACE %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
+      return 0;
+
+  const struct server_hunt *hunt = server_hunt(source_p, ":%s ETRACE :%s", 1, parc, parv);
+  switch (hunt->ret)
+  {
+    case HUNTED_PASS:
+      sendto_one_numeric(source_p, &me, RPL_TRACELINK,
+                         ircd_version, hunt->target_p->name, hunt->target_p->from->name);
+      break;
+    case HUNTED_ISME:
+      do_etrace(source_p, parv[1]);
+      break;
+    default:
+      break;
+  }
+
   return 0;
 }
 
@@ -126,7 +157,7 @@ static struct Message etrace_msgtab =
   .args_max = MAXPARA,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = mo_etrace,
   .handlers[ENCAP_HANDLER] = m_ignore,
   .handlers[OPER_HANDLER] = mo_etrace
 };
@@ -145,7 +176,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7909 $",
+  .version = "$Revision: 8083 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
