@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 7859 2016-11-08 20:09:29Z michael $
+ * \version $Id: m_info.c 8056 2017-03-22 18:36:24Z michael $
  */
 
 #include "stdinc.h"
@@ -232,6 +232,12 @@ static const struct InfoStruct info_table[] =
     &ConfigChannel.max_bans,
     "Total +b/e/I modes allowed in a channel"
   },
+  {
+    "max_bans_large",
+    OUTPUT_DECIMAL,
+    &ConfigChannel.max_bans_large,
+    "Total +b/e/I modes allowed in a +L channel"
+  },
   {
     "flatten_links",
     OUTPUT_BOOLEAN_YN,
@@ -374,7 +380,7 @@ static const struct InfoStruct info_table[] =
     "failed_oper_notice",
     OUTPUT_BOOLEAN_YN,
     &ConfigGeneral.failed_oper_notice,
-    "Inform opers if someone tries to /oper with the wrong password"
+    "Inform opers if someone tries to /oper with the wrong credentials"
   },
   {
     "dots_in_ident",
@@ -734,7 +740,7 @@ m_info(struct Client *source_p, int parc, char *parv[])
   last_used = CurrentTime;
 
   if (!ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s INFO :%s", 1, parc, parv) != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s INFO :%s", 1, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
   send_info_text(source_p);
@@ -755,7 +761,7 @@ m_info(struct Client *source_p, int parc, char *parv[])
 static int
 ms_info(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s INFO :%s", 1, parc, parv) != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s INFO :%s", 1, parc, parv)->ret != HUNTED_ISME)
     return 0;
 
   send_info_text(source_p);
@@ -787,7 +793,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7859 $",
+  .version = "$Revision: 8056 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
