@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_invite.c
  * \brief Includes required functions for processing the INVITE command.
- * \version $Id: m_invite.c 7903 2016-11-27 13:44:31Z michael $
+ * \version $Id: m_invite.c 8043 2017-03-18 16:51:06Z michael $
  */
 
 #include "stdinc.h"
@@ -142,11 +142,11 @@ m_invite(struct Client *source_p, int parc, char *parv[])
                source_p->host,
                target_p->name, chptr->name);
 
-    if (chptr->mode.mode & MODE_INVITEONLY)
+    if (HasCMode(chptr, MODE_INVITEONLY))
       add_invite(chptr, target_p);  /* Add the invite if channel is +i */
   }
 
-  if (chptr->mode.mode & MODE_INVITEONLY)
+  if (HasCMode(chptr, MODE_INVITEONLY))
   {
     sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, 0, CAP_INVITE_NOTIFY,
                          ":%s NOTICE %%%s :%s is inviting %s to %s.",
@@ -206,11 +206,11 @@ ms_invite(struct Client *source_p, int parc, char *parv[])
                source_p->host,
                target_p->name, chptr->name);
 
-    if (chptr->mode.mode & MODE_INVITEONLY)
+    if (HasCMode(chptr, MODE_INVITEONLY))
       add_invite(chptr, target_p);  /* Add the invite if channel is +i */
   }
 
-  if (chptr->mode.mode & MODE_INVITEONLY)
+  if (HasCMode(chptr, MODE_INVITEONLY))
   {
     sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, 0, CAP_INVITE_NOTIFY,
                          ":%s NOTICE %%%s :%s is inviting %s to %s.",
@@ -252,7 +252,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7903 $",
+  .version = "$Revision: 8043 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
