@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_ison.c
  * \brief Includes required functions for processing the ISON command.
- * \version $Id: m_ison.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_ison.c 8031 2017-03-17 16:16:04Z michael $
  */
 
 #include "stdinc.h"
@@ -48,7 +48,6 @@
 static int
 m_ison(struct Client *source_p, int parc, char *parv[])
 {
-  struct Client *target_p = NULL;
   char *nick;
   char *p = NULL;
   char *current_insert_point = NULL;
@@ -61,7 +60,8 @@ m_ison(struct Client *source_p, int parc, char *parv[])
   for (nick = strtok_r(parv[1], " ", &p); nick;
        nick = strtok_r(NULL,    " ", &p))
   {
-    if ((target_p = find_person(source_p, nick)))
+    const struct Client *target_p = find_person(source_p, nick);
+    if (target_p)
     {
       len = strlen(target_p->name);
 
@@ -109,7 +109,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 8031 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
