@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_links.c
  * \brief Includes required functions for processing the LINKS command.
- * \version $Id: m_links.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: m_links.c 7970 2017-03-13 21:55:33Z michael $
  */
 
 #include "stdinc.h"
@@ -103,8 +103,7 @@ mo_links(struct Client *source_p, int parc, char *parv[])
 {
   if (parc > 2)
     if (!ConfigServerHide.disable_remote_commands || HasUMode(source_p, UMODE_OPER))
-      if (hunt_server(source_p, ":%s LINKS %s :%s", 1,
-                      parc, parv) != HUNTED_ISME)
+      if (server_hunt(source_p, ":%s LINKS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
         return 0;
 
   do_links(source_p, parc, parv);
@@ -164,7 +163,7 @@ m_links(struct Client *source_p, int parc, char *parv[])
 static int
 ms_links(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s LINKS %s :%s", 1, parc, parv) != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s LINKS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
     return 0;
 
   return m_links(source_p, parc, parv);
@@ -195,7 +194,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7329 $",
+  .version = "$Revision: 7970 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
