@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_locops.c
  * \brief Includes required functions for processing the LOCOPS command.
- * \version $Id: m_locops.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_locops.c 7925 2016-12-31 13:57:24Z michael $
  */
 
 #include "stdinc.h"
@@ -31,6 +31,8 @@
 #include "numeric.h"
 #include "send.h"
 #include "conf.h"
+#include "conf_cluster.h"
+#include "conf_shared.h"
 #include "server.h"
 #include "parse.h"
 #include "modules.h"
@@ -66,7 +68,7 @@ mo_locops(struct Client *source_p, int parc, char *parv[])
 
   sendto_realops_flags(UMODE_LOCOPS, L_ALL, SEND_LOCOPS, "from %s: %s",
                        source_p->name, message);
-  cluster_a_line(source_p, "LOCOPS", 0, SHARED_LOCOPS, message);
+  cluster_distribute(source_p, "LOCOPS", 0, CLUSTER_LOCOPS, message);
   return 0;
 }
 
@@ -97,8 +99,7 @@ ms_locops(struct Client *source_p, int parc, char *parv[])
   if (match(targets, me.name))
     return 0;
 
-  if (find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
-                              "*", "*", SHARED_LOCOPS))
+  if (shared_find(SHARED_LOCOPS, source_p->servptr->name, "*", "*"))
     sendto_realops_flags(UMODE_LOCOPS, L_ALL, SEND_LOCOPS, "from %s: %s",
                          source_p->name, message);
   return 0;
@@ -130,7 +131,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7925 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
