@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_lusers.c
  * \brief Includes required functions for processing the LUSERS command.
- * \version $Id: m_lusers.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: m_lusers.c 7970 2017-03-13 21:55:33Z michael $
  */
 
 #include "stdinc.h"
@@ -62,7 +62,7 @@ m_lusers(struct Client *source_p, int parc, char *parv[])
   last_used = CurrentTime;
 
   if (!ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s LUSERS %s :%s", 2, parc, parv) != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s LUSERS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
   show_lusers(source_p);
@@ -84,7 +84,7 @@ m_lusers(struct Client *source_p, int parc, char *parv[])
 static int
 ms_lusers(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s LUSERS %s :%s", 2, parc, parv) != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s LUSERS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
     return 0;
 
   show_lusers(source_p);
@@ -116,7 +116,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7329 $",
+  .version = "$Revision: 7970 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
