@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2016 ircd-hybrid development team
+ *  Copyright (c) 2001-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_map.c
  * \brief Includes required functions for processing the MAP command.
- * \version $Id: m_map.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: m_map.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -38,13 +38,11 @@ static void dump_map(struct Client *client,
                      struct Client *server,
                      unsigned int prompt_length)
 {
-  dlink_node *node = NULL;
-  struct Client *target_p = NULL;
+  dlink_node *node;
   static char prompt[64];
   char buf[IRCD_BUFSIZE];
   char *p = prompt + prompt_length;
   unsigned int cnt = 0;
-  unsigned int bufpos = 0;
 
   *p = '\0';
 
@@ -52,24 +50,23 @@ static void dump_map(struct Client *client,
     sendto_one_numeric(client, &me, RPL_MAPMORE, prompt, server->name);
   else
   {
-    int dashes;
-
-    bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos, "%s", server->name);
+    unsigned int bufpos = snprintf(buf, sizeof(buf), "%s", server->name);
 
     if (HasUMode(client, UMODE_OPER))
       bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos, "[%s]", server->id);
 
     buf[bufpos++] = ' ';
-    dashes = 50 - bufpos - prompt_length;
-    for (; dashes > 0; --dashes)
+
+    for (int dashes = 50 - bufpos - prompt_length; dashes > 0; --dashes)
       buf[bufpos++] = '-';
+
     buf[bufpos++] = ' ';
     buf[bufpos++] = '|';
 
     bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos, " Users: %5d (%1.2f%%)",
                        dlink_list_length(&server->serv->client_list), 100 *
                        (float)dlink_list_length(&server->serv->client_list) /
-                       (float)Count.total);
+                       (float)dlink_list_length(&global_client_list));
     sendto_one_numeric(client, &me, RPL_MAP, prompt, buf);
   }
 
@@ -87,7 +84,7 @@ static void dump_map(struct Client *client,
 
   DLINK_FOREACH(node, server->serv->server_list.head)
   {
-    target_p = node->data;
+    struct Client *target_p = node->data;
 
     if (IsHidden(target_p) && !HasUMode(client, UMODE_OPER))
       continue;
@@ -101,7 +98,7 @@ static void dump_map(struct Client *client,
 
   DLINK_FOREACH(node, server->serv->server_list.head)
   {
-    target_p = node->data;
+    struct Client *target_p = node->data;
 
     if (IsHidden(target_p) && !HasUMode(client, UMODE_OPER))
       continue;
@@ -208,7 +205,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7329 $",
+  .version = "$Revision: 8058 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
