@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2016 ircd-hybrid development team
+ *  Copyright (c) 2000-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_module.c
  * \brief Includes required functions for processing the MODULE command.
- * \version $Id: m_module.c 7686 2016-08-18 17:32:04Z michael $
+ * \version $Id: m_module.c 8073 2017-03-25 19:42:32Z michael $
  */
 
 #include "stdinc.h"
@@ -103,17 +103,14 @@ module_reload(struct Client *source_p, const char *arg)
 {
   const char *m_bn = NULL;
   struct module *modp = NULL;
-  int check_core = 0;
 
   if (!strcmp(arg, "*"))
   {
-    unsigned int modnum = 0;
-    dlink_node *node = NULL, *node_next = NULL;
+    unsigned int modnum = dlink_list_length(modules_get_list());
+    dlink_node *node, *node_next;
 
     sendto_one_notice(source_p, &me, ":Reloading all modules");
 
-    modnum = dlink_list_length(modules_get_list());
-
     DLINK_FOREACH_SAFE(node, node_next, modules_get_list()->head)
     {
       modp = node->data;
@@ -147,21 +144,20 @@ module_reload(struct Client *source_p, const char *arg)
     return;
   }
 
-  check_core = (modp->flags & MODULE_FLAG_CORE) != 0;
-
   if (unload_one_module(m_bn, 1) == -1)
   {
     sendto_one_notice(source_p, &me, ":Module %s is not loaded", m_bn);
     return;
   }
 
-  if ((load_one_module(arg) == -1) && check_core)
+  int check_core = (modp->flags & MODULE_FLAG_CORE) != 0;
+  if (load_one_module(arg) == -1 && check_core)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error reloading core "
                          "module: %s: terminating ircd", arg);
     ilog(LOG_TYPE_IRCD, "Error loading core module %s: terminating ircd", arg);
-    exit(0);
+    exit(EXIT_FAILURE);
   }
 }
 
@@ -283,7 +279,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7686 $",
+  .version = "$Revision: 8073 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_NOUNLOAD
