@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_names.c
  * \brief Includes required functions for processing the NAMES command.
- * \version $Id: m_names.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_names.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -51,12 +51,12 @@
 static int
 m_names(struct Client *source_p, int parc, char *parv[])
 {
-  struct Channel *chptr = NULL;
   const char *const para = parc > 1 ? parv[1] : NULL;
 
   if (!EmptyString(para))
   {
-    if ((chptr = hash_find_channel(para)))
+    struct Channel *chptr = hash_find_channel(para);
+    if (chptr)
       channel_member_names(source_p, chptr, 1);
     else
       sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, para);
@@ -92,7 +92,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 8058 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
