@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_pass.c
  * \brief Includes required functions for processing the PASS command.
- * \version $Id: m_pass.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: m_pass.c 7993 2017-03-14 12:28:29Z michael $
  */
 
 #include "stdinc.h"
@@ -33,8 +33,6 @@
 #include "ircd.h"
 #include "parse.h"
 #include "modules.h"
-#include "server.h"
-#include "user.h"
 #include "misc.h"
 #include "memory.h"
 
@@ -50,8 +48,8 @@
  *      - parv[0] = command
  *      - parv[1] = password
  *      - parv[2] = unused
- *      - parv[3] = TS protocol version
- *      - parv[4] = server ID (SID)
+ *      - parv[3] = TS protocol version (will be deprecated in some future release)
+ *      - parv[4] = server ID (SID) (will be deprecated in some future release)
  */
 static int
 mr_pass(struct Client *source_p, int parc, char *parv[])
@@ -101,7 +99,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7033 $",
+  .version = "$Revision: 7993 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
