@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_restart.c
  * \brief Includes required functions for processing the RESTART command.
- * \version $Id: m_restart.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_restart.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -71,15 +71,20 @@ mo_restart(struct Client *source_p, int parc, char *parv[])
   }
 
   snprintf(buf, sizeof(buf), "received RESTART command from %s",
-           get_client_name(source_p, HIDE_IP));
-  server_die(buf, 1);
+           client_get_name(source_p, HIDE_IP));
+  server_die(buf, SERVER_RESTART);
   return 0;
 }
 
 static struct Message restart_msgtab =
 {
-  "RESTART", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_restart, m_ignore }
+  .cmd = "RESTART",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_restart
 };
 
 static void
@@ -96,11 +101,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7996 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
