@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_stats.c
  * \brief Includes required functions for processing the STATS command.
- * \version $Id: m_stats.c 7913 2016-11-27 18:54:38Z michael $
+ * \version $Id: m_stats.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -218,16 +218,14 @@ stats_connect(struct Client *source_p, int parc, char *parv[])
     *p = '\0';
 
     /*
-     * Allow admins to see actual ips unless hide_server_ips is enabled
+     * Allow admins to see actual ips unless 'hide_server_ips' is enabled
      */
     if (!ConfigServerHide.hide_server_ips && HasUMode(source_p, UMODE_ADMIN))
       sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C', conf->host,
-                         buf, conf->name, conf->port,
-                         conf->class->name);
+                         buf, conf->name, conf->port, conf->class->name);
     else
-      sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C',
-                         "*@127.0.0.1", buf, conf->name, conf->port,
-                         conf->class->name);
+      sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C', "*@127.0.0.1",
+                         buf, conf->name, conf->port, conf->class->name);
   }
 }
 
@@ -267,7 +265,6 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   dlink_node *node, *node2;
 
   unsigned int local_client_conf_count = 0;      /* local client conf links */
-  unsigned int users_counted = 0;                /* user structs */
 
   unsigned int channel_members = 0;
   unsigned int channel_invites = 0;
@@ -302,23 +299,24 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   size_t listener_memory = 0;
 
 
-  DLINK_FOREACH(node, global_client_list.head)
+  DLINK_FOREACH(node, local_server_list.head)
   {
     const struct Client *target_p = node->data;
 
-    if (MyConnect(target_p))
-    {
-      ++local_client_count;
-      local_client_conf_count += dlink_list_length(&target_p->connection->confs);
-      watch_list_entries += dlink_list_length(&target_p->connection->watches);
-    }
-    else
-      ++remote_client_count;
-
-    if (IsClient(target_p))
-      ++users_counted;
+    local_client_conf_count += dlink_list_length(&target_p->connection->confs);
   }
 
+  DLINK_FOREACH(node, local_client_list.head)
+  {
+    const struct Client *target_p = node->data;
+
+    local_client_conf_count += dlink_list_length(&target_p->connection->confs);
+    watch_list_entries += dlink_list_length(&target_p->connection->watches);
+  }
+
+  local_client_count = dlink_list_length(&local_server_list) + dlink_list_length(&local_client_list);
+  remote_client_count = dlink_list_length(&global_server_list) + dlink_list_length(&global_client_list) - local_client_count;
+
   /* Count up all members, invites, ban lists, except lists, Invex lists */
   DLINK_FOREACH(node, channel_list.head)
   {
@@ -364,8 +362,14 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Clients %u(%zu)",
-                     users_counted,
-                     users_counted * sizeof(struct Client));
+                     dlink_list_length(&global_client_list),
+                     dlink_list_length(&global_client_list) * sizeof(struct Client));
+
+  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
+                     "z :Servers %u(%zu, %zu)",
+                     dlink_list_length(&global_server_list),
+                     dlink_list_length(&global_server_list) * sizeof(struct Client),
+                     dlink_list_length(&global_server_list) * sizeof(struct Server));
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Attached confs %u(%zu)",
@@ -986,7 +990,7 @@ stats_uptime(struct Client *source_p, int parc, char *parv[])
                        time_dissect(CurrentTime - me.connection->since));
     if (!ConfigServerHide.disable_remote_commands || HasUMode(source_p, UMODE_OPER))
        sendto_one_numeric(source_p, &me, RPL_STATSCONN, Count.max_loc_con,
-                          Count.max_loc_cli, Count.totalrestartcount);
+                          Count.max_loc, Count.totalrestartcount);
   }
 }
 
@@ -1071,7 +1075,7 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
 
     /* ":%s 211 %s %s %u %u %ju %u %ju :%u %u %s" */
     sendto_one_numeric(source_p, &me, RPL_STATSLINKINFO,
-               get_client_name(target_p, HasUMode(source_p, UMODE_ADMIN) ? SHOW_IP : MASK_IP),
+               client_get_name(target_p, HasUMode(source_p, UMODE_ADMIN) ? SHOW_IP : MASK_IP),
                dbuf_length(&target_p->connection->buf_sendq),
                target_p->connection->send.messages,
                target_p->connection->send.bytes >> 10,
@@ -1170,7 +1174,7 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
         type = MASK_IP;
 
     sendto_one_numeric(source_p, &me, RPL_STATSLINKINFO,
-                       get_client_name(target_p, type),
+                       client_get_name(target_p, type),
                        dbuf_length(&target_p->connection->buf_sendq),
                        target_p->connection->send.messages,
                        target_p->connection->send.bytes >> 10,
@@ -1318,7 +1322,7 @@ m_stats(struct Client *source_p, int parc, char *parv[])
 
   /* Is the stats meant for us? */
   if (!ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s STATS %s :%s", 2, parc, parv) != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s STATS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
   do_stats(source_p, parc, parv);
@@ -1334,7 +1338,7 @@ m_stats(struct Client *source_p, int parc, char *parv[])
 static int
 ms_stats(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s STATS %s :%s", 2, parc, parv) != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s STATS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
      return 0;
 
   do_stats(source_p, parc, parv);
@@ -1375,7 +1379,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7913 $",
+  .version = "$Revision: 8058 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
