@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svinfo.c
  * \brief Includes required functions for processing the SVINFO command.
- * \version $Id: m_svinfo.c 7648 2016-07-17 14:37:14Z michael $
+ * \version $Id: m_svinfo.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -66,13 +66,13 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
      */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
          "Link %s dropped, wrong TS protocol version (%s,%s)",
-         get_client_name(source_p, SHOW_IP), parv[1], parv[2]);
+         client_get_name(source_p, SHOW_IP), parv[1], parv[2]);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
          "Link %s dropped, wrong TS protocol version (%s,%s)",
-         get_client_name(source_p, MASK_IP), parv[1], parv[2]);
+         client_get_name(source_p, MASK_IP), parv[1], parv[2]);
     ilog(LOG_TYPE_IRCD,
          "Link %s dropped, wrong TS protocol version (%s,%s)",
-         get_client_name(source_p, SHOW_IP), parv[1], parv[2]);
+         client_get_name(source_p, SHOW_IP), parv[1], parv[2]);
 
     exit_client(source_p, "Incompatible TS version");
     return 0;
@@ -90,13 +90,13 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
          "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-         get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+         client_get_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
          "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-         get_client_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
+         client_get_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
     ilog(LOG_TYPE_IRCD,
          "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-         get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+         client_get_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
 
     exit_client(source_p, "Excessive TS delta");
     return 0;
@@ -106,10 +106,10 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
           "Link %s notable TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-          get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+          client_get_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
           "Link %s notable TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-          get_client_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
+          client_get_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
   }
 
   return 0;
@@ -141,7 +141,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7648 $",
+  .version = "$Revision: 7996 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
