@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2016 ircd-hybrid development team
+ *  Copyright (c) 2014-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svsjoin.c
  * \brief Includes required functions for processing the SVSJOIN command.
- * \version $Id: m_svsjoin.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_svsjoin.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -75,7 +75,7 @@ ms_svsjoin(struct Client *source_p, int parc, char *parv[])
                          "Received wrong-direction SVSJOIN "
                          "for %s (behind %s) from %s",
                          target_p->name, source_p->from->name,
-                         get_client_name(source_p, HIDE_IP));
+                         client_get_name(source_p, HIDE_IP));
     return 0;
   }
 
@@ -114,7 +114,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7996 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
