@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2013-2016 ircd-hybrid development team
+ *  Copyright (c) 2013-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svskill.c
  * \brief Includes required functions for processing the SVSKILL command.
- * \version $Id: m_svskill.c 7512 2016-03-26 19:55:16Z michael $
+ * \version $Id: m_svskill.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -89,7 +89,7 @@ ms_svskill(struct Client *source_p, int parc, char *parv[])
                          "Received wrong-direction SVSKILL "
                          "for %s (behind %s) from %s",
                          target_p->name, source_p->from->name,
-                         get_client_name(source_p, HIDE_IP));
+                         client_get_name(source_p, HIDE_IP));
     return 0;
   }
 
@@ -128,7 +128,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7512 $",
+  .version = "$Revision: 7996 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
