@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_topic.c
  * \brief Includes required functions for processing the TOPIC command.
- * \version $Id: m_topic.c 7089 2016-01-22 17:19:55Z michael $
+ * \version $Id: m_topic.c 8043 2017-03-18 16:51:06Z michael $
  */
 
 #include "stdinc.h"
@@ -83,8 +83,8 @@ m_topic(struct Client *source_p, int parc, char *parv[])
       return 0;
     }
 
-    if (!(chptr->mode.mode & MODE_TOPICLIMIT) ||
-        has_member_flags(member, CHFL_CHANOP|CHFL_HALFOP))
+    if (!HasCMode(chptr, MODE_TOPICLIMIT) ||
+        has_member_flags(member, CHFL_CHANOP | CHFL_HALFOP))
     {
       char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
 
@@ -209,7 +209,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7089 $",
+  .version = "$Revision: 8043 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
