@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2016 ircd-hybrid development team
+ *  Copyright (c) 2003-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unxline.c
  * \brief Includes required functions for processing the UNXLINE command.
- * \version $Id: m_unxline.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_unxline.c 7925 2016-12-31 13:57:24Z michael $
  */
 
 #include "stdinc.h"
@@ -30,6 +30,9 @@
 #include "irc_string.h"
 #include "ircd.h"
 #include "conf.h"
+#include "conf_cluster.h"
+#include "conf_gecos.h"
+#include "conf_shared.h"
 #include "numeric.h"
 #include "log.h"
 #include "send.h"
@@ -46,20 +49,15 @@
  * Side effects: Any matching tklines are removed.
  */
 static int
-xline_remove(const char *gecos)
+xline_remove(const char *mask)
 {
-  dlink_node *node = NULL;
+  struct GecosItem *gecos;
 
-  DLINK_FOREACH(node, gecos_items.head)
+  if ((gecos = gecos_find(mask, irccmp)))
   {
-    struct MaskItem *conf = node->data;
-
-    if (!IsConfDatabase(conf))
-      continue;
-
-    if (!irccmp(gecos, conf->name))
+    if (gecos->in_database)
     {
-      conf_free(conf);
+      gecos_delete(gecos);
       return 1;
     }
   }
@@ -110,7 +108,7 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!parse_aline("UNXLINE", source_p, parc, parv, 0, &gecos,
+  if (!parse_aline("UNXLINE", source_p, parc, parv, &gecos,
                    NULL, NULL, &target_server, NULL))
     return 0;
 
@@ -124,7 +122,7 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
       return 0;
   }
   else
-    cluster_a_line(source_p, "UNXLINE", CAPAB_CLUSTER, SHARED_UNXLINE, "%s", gecos);
+    cluster_distribute(source_p, "UNXLINE", CAPAB_CLUSTER, CLUSTER_UNXLINE, "%s", gecos);
 
   xline_remove_and_notify(source_p, gecos);
   return 0;
@@ -139,7 +137,7 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *      - parv[0] = command
- *      - parv[1] = target server
+ *      - parv[1] = target server mask
  *      - parv[2] = gecos
  */
 static int
@@ -155,9 +153,8 @@ ms_unxline(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
-                              source_p->username, source_p->host,
-                              SHARED_UNXLINE))
+      shared_find(SHARED_UNXLINE, source_p->servptr->name,
+                  source_p->username, source_p->host))
     xline_remove_and_notify(source_p, parv[2]);
   return 0;
 }
@@ -188,7 +185,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7925 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
