@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_userhost.c
  * \brief Includes required functions for processing the USERHOST command.
- * \version $Id: m_userhost.c 7047 2016-01-10 12:38:40Z michael $
+ * \version $Id: m_userhost.c 8031 2017-03-17 16:16:04Z michael $
  */
 
 #include "stdinc.h"
@@ -48,9 +48,8 @@
 static int
 m_userhost(struct Client *source_p, int parc, char *parv[])
 {
-  struct Client *target_p;
   char buf[IRCD_BUFSIZE];
-  char response[NICKLEN*2+USERLEN+HOSTLEN+30];
+  char response[NICKLEN * 2 + USERLEN + HOSTLEN + 30];
   char *t = NULL, *p = NULL, *nick = NULL;
   int i = 0;
   int cur_len;
@@ -62,7 +61,8 @@ m_userhost(struct Client *source_p, int parc, char *parv[])
   for (nick = strtok_r(parv[1], " ", &p); nick && i++ < 5;
        nick = strtok_r(NULL,    " ", &p))
   {
-    if ((target_p = find_person(source_p, nick)))
+    const struct Client *target_p = find_person(source_p, nick);
+    if (target_p)
     {
       /*
        * Show real IP address for USERHOST on yourself.
@@ -131,7 +131,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7047 $",
+  .version = "$Revision: 8031 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
