@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_who.c
  * \brief Includes required functions for processing the WHO command.
- * \version $Id: m_who.c 7644 2016-07-16 17:56:53Z michael $
+ * \version $Id: m_who.c 7962 2017-03-13 18:48:59Z michael $
  */
 
 #include "stdinc.h"
@@ -204,8 +204,7 @@ who_global(struct Client *source_p, const char *mask, int server_oper)
   {
     struct Client *target_p = node->data;
 
-    if (!IsClient(target_p))
-      continue;
+    assert(IsClient(target_p));
 
     if (HasUMode(target_p, UMODE_INVISIBLE))
     {
@@ -385,7 +384,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7644 $",
+  .version = "$Revision: 7962 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
