@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whois.c
  * \brief Includes required functions for processing the WHOIS command.
- * \version $Id: m_whois.c 7871 2016-11-09 20:13:07Z michael $
+ * \version $Id: m_whois.c 7970 2017-03-13 21:55:33Z michael $
  */
 
 #include "stdinc.h"
@@ -271,8 +271,7 @@ m_whois(struct Client *source_p, int parc, char *parv[])
     if (ConfigServerHide.disable_remote_commands)
       parv[1] = parv[2];
 
-    if (hunt_server(source_p, ":%s WHOIS %s :%s", 1,
-                    parc, parv) != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
     parv[1] = parv[2];
@@ -305,8 +304,7 @@ mo_whois(struct Client *source_p, int parc, char *parv[])
 
   if (parc > 2 && !EmptyString(parv[2]))
   {
-    if (hunt_server(source_p, ":%s WHOIS %s :%s", 1,
-                    parc, parv) != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
     parv[1] = parv[2];
@@ -341,7 +339,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7871 $",
+  .version = "$Revision: 7970 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
