@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whowas.c
  * \brief Includes required functions for processing the WHOWAS command.
- * \version $Id: m_whowas.c 7686 2016-08-18 17:32:04Z michael $
+ * \version $Id: m_whowas.c 7988 2017-03-14 00:39:46Z michael $
  */
 
 #include "stdinc.h"
@@ -45,8 +45,7 @@ enum { WHOWAS_MAX_REPLIES = 20 };  /* Only applies to remote clients */
 static void
 do_whowas(struct Client *source_p, const int parc, char *parv[])
 {
-  int cur = 0;
-  int max = -1;
+  int count = 0, max = -1;
   dlink_node *node;
 
   if (parc > 2 && !EmptyString(parv[2]))
@@ -79,14 +78,14 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
       else
         sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, whowas->name,
                            whowas->servername, date_ctime(whowas->logoff));
-      ++cur;
+      ++count;
     }
 
-    if (max > 0 && cur >= max)
+    if (max > 0 && count >= max)
       break;
   }
 
-  if (!cur)
+  if (!count)
     sendto_one_numeric(source_p, &me, ERR_WASNOSUCHNICK, parv[1]);
 
   sendto_one_numeric(source_p, &me, RPL_ENDOFWHOWAS, parv[1]);
@@ -125,7 +124,7 @@ m_whowas(struct Client *source_p, int parc, char *parv[])
   last_used = CurrentTime;
 
   if (!ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv) != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
   do_whowas(source_p, parc, parv);
@@ -154,7 +153,7 @@ ms_whowas(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (hunt_server(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv) != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv)->ret != HUNTED_ISME)
     return 0;
 
   do_whowas(source_p, parc, parv);
@@ -186,7 +185,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7686 $",
+  .version = "$Revision: 7988 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
