@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel.c
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.c 7913 2016-11-27 18:54:38Z michael $
+ * \version $Id: channel.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -55,9 +55,6 @@ static mp_pool_t *member_pool, *channel_pool, *invite_pool;
 void
 channel_init(void)
 {
-  add_capability("EX", CAPAB_EX);
-  add_capability("IE", CAPAB_IE);
-
   invite_pool = mp_pool_new(sizeof(struct Invite), MP_CHUNK_SIZE_INVITE);
   channel_pool = mp_pool_new(sizeof(struct Channel), MP_CHUNK_SIZE_CHANNEL);
   ban_pool = mp_pool_new(sizeof(struct Ban), MP_CHUNK_SIZE_BAN);
@@ -100,7 +97,7 @@ add_user_to_channel(struct Channel *chptr, struct Client *client_p,
         SetJoinFloodNoticed(chptr);
         sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
                              "Possible Join Flooder %s on %s target: %s",
-                             get_client_name(client_p, HIDE_IP),
+                             client_get_name(client_p, HIDE_IP),
                              client_p->servptr->name, chptr->name);
       }
     }
@@ -154,8 +151,8 @@ static void
 channel_send_members(struct Client *client_p, const struct Channel *chptr,
                      const char *modebuf, const char *parabuf)
 {
-  char buf[IRCD_BUFSIZE] = "";
   dlink_node *node;
+  char buf[IRCD_BUFSIZE] = "";
   int tlen;              /* length of text to append */
   char *t, *start;       /* temp char pointer */
 
@@ -343,6 +340,7 @@ channel_make(const char *name)
   chptr->creationtime = CurrentTime;
   chptr->last_join_time = CurrentTime;
 
+  /* Cache channel name length to avoid repetitive strlen() calls. */
   chptr->name_len = strlcpy(chptr->name, name, sizeof(chptr->name));
   if (chptr->name_len >= sizeof(chptr->name))
     chptr->name_len = sizeof(chptr->name) - 1;
@@ -501,9 +499,8 @@ find_invite(struct Channel *chptr, struct Client *client_p)
 void
 add_invite(struct Channel *chptr, struct Client *client_p)
 {
-  struct Invite *invite;
-
-  if ((invite = find_invite(chptr, client_p)))
+  struct Invite *invite = find_invite(chptr, client_p);
+  if (invite)
     del_invite(invite);
 
   invite = mp_pool_get(invite_pool);
@@ -556,7 +553,7 @@ clear_invite_list(dlink_list *list)
  * side effects -
  *
  * NOTE: Returned string is usually a static buffer
- * (like in get_client_name)
+ * (like in client_get_name)
  */
 const char *
 get_member_status(const struct Membership *member, const int combine)
@@ -651,16 +648,16 @@ is_banned(const struct Channel *chptr, const struct Client *client_p)
 static int
 can_join(struct Client *client_p, struct Channel *chptr, const char *key)
 {
-  if ((chptr->mode.mode & MODE_SSLONLY) && !HasUMode(client_p, UMODE_SSL))
+  if (HasCMode(chptr, MODE_SSLONLY) && !HasUMode(client_p, UMODE_SSL))
     return ERR_SSLONLYCHAN;
 
-  if ((chptr->mode.mode & MODE_REGONLY) && !HasUMode(client_p, UMODE_REGISTERED))
+  if (HasCMode(chptr, MODE_REGONLY) && !HasUMode(client_p, UMODE_REGISTERED))
     return ERR_NEEDREGGEDNICK;
 
-  if ((chptr->mode.mode & MODE_OPERONLY) && !HasUMode(client_p, UMODE_OPER))
+  if (HasCMode(chptr, MODE_OPERONLY) && !HasUMode(client_p, UMODE_OPER))
     return ERR_OPERONLYCHAN;
 
-  if (chptr->mode.mode & MODE_INVITEONLY)
+  if (HasCMode(chptr, MODE_INVITEONLY))
     if (!find_invite(chptr, client_p))
       if (!find_bmask(client_p, &chptr->invexlist))
         return ERR_INVITEONLYCHAN;
@@ -762,10 +759,10 @@ can_send(struct Channel *chptr, struct Client *client_p,
       if ((resv = resv_find(chptr->name, match)) && !resv_exempt_find(client_p, resv))
         return ERR_CANNOTSENDTOCHAN;
 
-  if ((chptr->mode.mode & MODE_NOCTRL) && msg_has_ctrls(message))
+  if (HasCMode(chptr, MODE_NOCTRL) && msg_has_ctrls(message))
     return ERR_NOCTRLSONCHAN;
 
-  if (chptr->mode.mode & MODE_NOCTCP)
+  if (HasCMode(chptr, MODE_NOCTCP))
     if (*message == '\001' && strncmp(message + 1, "ACTION ", 7))
       return ERR_NOCTCP;
 
@@ -773,16 +770,16 @@ can_send(struct Channel *chptr, struct Client *client_p,
     if (member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE))
       return CAN_SEND_OPV;
 
-  if (!member && (chptr->mode.mode & MODE_NOPRIVMSGS))
+  if (!member && HasCMode(chptr, MODE_NOPRIVMSGS))
     return ERR_CANNOTSENDTOCHAN;
 
-  if (chptr->mode.mode & MODE_MODERATED)
+  if (HasCMode(chptr, MODE_MODERATED))
     return ERR_CANNOTSENDTOCHAN;
 
-  if ((chptr->mode.mode & MODE_MODREG) && !HasUMode(client_p, UMODE_REGISTERED))
+  if (HasCMode(chptr, MODE_MODREG) && !HasUMode(client_p, UMODE_REGISTERED))
     return ERR_NEEDREGGEDNICK;
 
-  if ((chptr->mode.mode & MODE_NONOTICE) && notice)
+  if (HasCMode(chptr, MODE_NONOTICE) && notice)
     return ERR_CANNOTSENDTOCHAN;
 
   /* Cache can send if banned */
@@ -994,7 +991,7 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
       sendto_one_numeric(client_p, &me, ERR_CHANBANREASON, name, resv->reason);
       sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                            "Forbidding reserved channel %s from user %s",
-                           name, get_client_name(client_p, HIDE_IP));
+                           name, client_get_name(client_p, HIDE_IP));
       continue;
     }
 
@@ -1005,8 +1002,8 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
       break;
     }
 
-    struct Channel *chptr;
-    if ((chptr = hash_find_channel(name)))
+    struct Channel *chptr = hash_find_channel(name);
+    if (chptr)
     {
       if (IsMember(client_p, chptr))
         continue;
@@ -1045,8 +1042,8 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
     if (flags == CHFL_CHANOP)
     {
       chptr->creationtime = CurrentTime;
-      chptr->mode.mode |= MODE_TOPICLIMIT;
-      chptr->mode.mode |= MODE_NOPRIVMSGS;
+      AddCMode(chptr, MODE_TOPICLIMIT);
+      AddCMode(chptr, MODE_NOPRIVMSGS);
 
       sendto_server(client_p, 0, 0, ":%s SJOIN %ju %s +nt :@%s",
                     me.id, chptr->creationtime,
