@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.c
  * \brief Controls modes on channels.
- * \version $Id: channel_mode.c 7796 2016-10-18 17:26:37Z michael $
+ * \version $Id: channel_mode.c 8050 2017-03-19 11:25:27Z michael $
  */
 
 #include "stdinc.h"
@@ -40,13 +40,8 @@
 #include "mempool.h"
 #include "parse.h"
 
-/* 10 is a magic number in hybrid 6 NFI where it comes from -db */
-#define BAN_FUDGE       10
 
 static char nuh_mask[MAXPARA][IRCD_BUFSIZE];
-/* some buffers for rebuilding channel/nick lists with ,'s */
-static char modebuf[IRCD_BUFSIZE];
-static char parabuf[MODEBUFLEN];
 static struct ChModeChange mode_changes[IRCD_BUFSIZE];
 static unsigned int mode_count;
 static unsigned int mode_limit;  /* number of modes set other than simple */
@@ -63,7 +58,9 @@ const struct mode_letter chan_modes[] =
   { MODE_REGISTERED, 'r' },
   { MODE_SECRET,     's' },
   { MODE_TOPICLIMIT, 't' },
+  { MODE_HIDEBMASKS, 'u' },
   { MODE_NOCTCP,     'C' },
+  { MODE_EXTLIMIT,   'L' },
   { MODE_MODREG,     'M' },
   { MODE_OPERONLY,   'O' },
   { MODE_REGONLY,    'R' },
@@ -120,14 +117,15 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
   char host[HOSTLEN + 1] = "";
   struct split_nuh_item nuh;
 
-  /* Don't let local clients overflow the b/e/I lists */
   if (MyClient(client_p))
   {
     unsigned int num_mask = dlink_list_length(&chptr->banlist) +
                             dlink_list_length(&chptr->exceptlist) +
                             dlink_list_length(&chptr->invexlist);
 
-    if (num_mask >= ConfigChannel.max_bans)
+    /* Don't let local clients overflow the b/e/I lists */
+    if (num_mask >= ((HasCMode(chptr, MODE_EXTLIMIT)) ? ConfigChannel.max_bans_large :
+                                                        ConfigChannel.max_bans))
     {
       sendto_one_numeric(client_p, &me, ERR_BANLISTFULL, chptr->name, banid);
       return 0;
@@ -287,7 +285,7 @@ channel_modes(struct Channel *chptr, struct Client *client_p, char *mbuf, char *
   *pbuf = '\0';
 
   for (const struct mode_letter *tab = chan_modes; tab->mode; ++tab)
-    if (chptr->mode.mode & tab->mode)
+    if (HasCMode(chptr, tab->mode))
       *mbuf++ = tab->letter;
 
   if (chptr->mode.limit)
@@ -322,7 +320,7 @@ fix_key(char *arg)
 {
   unsigned char *s, *t, c;
 
-  for (s = t = (unsigned char *)arg; (c = *s); ++s)
+  for (s = t = (unsigned char *)arg; (c = *s) && s - (unsigned char *)arg < KEYLEN; ++s)
   {
     c &= 0x7f;
 
@@ -363,8 +361,8 @@ enum
   SM_ERR_RPL_E        = 1 << 3,
   SM_ERR_RPL_I        = 1 << 4,
   SM_ERR_NOTONCHANNEL = 1 << 5,  /* Client is not on channel */
-  SM_ERR_NOTOPER      = 1 << 6,
-  SM_ERR_ONLYSERVER   = 1 << 7
+  SM_ERR_NOTOPER      = 1 << 6,  /* Only irc-operators can change that mode */
+  SM_ERR_ONLYSERVER   = 1 << 7   /* Only servers or services can change that mode */
 };
 
 /* Mode functions handle mode changes for a particular mode... */
@@ -401,31 +399,25 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   simple_modes_mask |= d;
 
   /* setting + */
-  /* Apparently, (though no one has ever told the hybrid group directly)
-   * admins don't like redundant mode checking. ok. It would have been nice
-   * if you had have told us directly. I've left the original code snippets
-   * in place.
-   *
-   * -Dianora
-   */
   if (dir == MODE_ADD) /* && !(chptr->mode.mode & d)) */
   {
-    chptr->mode.mode |= d;
+    AddCMode(chptr, d);
 
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL) /* && (chptr->mode.mode & d)) */
   {
     /* setting - */
-
-    chptr->mode.mode &= ~d;
+    DelCMode(chptr, d);
 
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
 }
@@ -452,38 +444,32 @@ chm_registered(struct Client *source_p, struct Channel *chptr, int parc, int *pa
   simple_modes_mask |= d;
 
   /* setting + */
-  /* Apparently, (though no one has ever told the hybrid group directly)
-   * admins don't like redundant mode checking. ok. It would have been nice
-   * if you had have told us directly. I've left the original code snippets
-   * in place.
-   *
-   * -Dianora
-   */
   if (dir == MODE_ADD) /* && !(chptr->mode.mode & d)) */
   {
-    chptr->mode.mode |= d;
+    AddCMode(chptr, d);
 
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL) /* && (chptr->mode.mode & d)) */
   {
     /* setting - */
-
-    chptr->mode.mode &= ~d;
+    DelCMode(chptr, d);
 
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
 }
 
 static void
-chm_operonly(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
-             char **parv, int *errors, int alev, int dir, char c, unsigned int d)
+chm_simple_oper(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
+                char **parv, int *errors, int alev, int dir, char c, unsigned int d)
 {
   if (alev < CHACCESS_HALFOP)
   {
@@ -513,22 +499,23 @@ chm_operonly(struct Client *source_p, struct Channel *chptr, int parc, int *parn
 
   if (dir == MODE_ADD) /* && !(chptr->mode.mode & d)) */
   {
-    chptr->mode.mode |= d;
+    AddCMode(chptr, d);
 
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL) /* && (chptr->mode.mode & d)) */
   {
     /* setting - */
-
-    chptr->mode.mode &= ~d;
+    DelCMode(chptr, d);
 
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
 }
@@ -549,9 +536,11 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     DLINK_FOREACH(node, chptr->banlist.head)
     {
       const struct Ban *ban = node->data;
-      sendto_one_numeric(source_p, &me, RPL_BANLIST, chptr->name,
-                         ban->name, ban->user, ban->host,
-                         ban->who, ban->when);
+
+      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= CHACCESS_HALFOP)
+        sendto_one_numeric(source_p, &me, RPL_BANLIST, chptr->name,
+                           ban->name, ban->user, ban->host,
+                           ban->who, ban->when);
     }
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFBANLIST, chptr->name);
@@ -572,7 +561,7 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
     return;
 
-  char *mask = nuh_mask[*parn];
+  char *const mask = nuh_mask[*parn];
   strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
   ++(*parn);
 
@@ -594,8 +583,12 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   }
 
   mode_changes[mode_count].letter = c;
-  mode_changes[mode_count].arg = mask;
+  mode_changes[mode_count].arg = mask;  /* At this point 'mask' is no longer than NICKLEN + USERLEN + HOSTLEN + 3 */
   mode_changes[mode_count].id = NULL;
+  if (HasCMode(chptr, MODE_HIDEBMASKS))
+    mode_changes[mode_count].flags = CHFL_CHANOP | CHFL_HALFOP;
+  else
+    mode_changes[mode_count].flags = 0;
   mode_changes[mode_count++].dir = dir;
 }
 
@@ -615,9 +608,11 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     DLINK_FOREACH(node, chptr->exceptlist.head)
     {
       const struct Ban *ban = node->data;
-      sendto_one_numeric(source_p, &me, RPL_EXCEPTLIST, chptr->name,
-                         ban->name, ban->user, ban->host,
-                         ban->who, ban->when);
+
+      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= CHACCESS_HALFOP)
+        sendto_one_numeric(source_p, &me, RPL_EXCEPTLIST, chptr->name,
+                           ban->name, ban->user, ban->host,
+                           ban->who, ban->when);
     }
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFEXCEPTLIST, chptr->name);
@@ -638,7 +633,7 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
     return;
 
-  char *mask = nuh_mask[*parn];
+  char *const mask = nuh_mask[*parn];
   strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
   ++(*parn);
 
@@ -660,8 +655,12 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   }
 
   mode_changes[mode_count].letter = c;
-  mode_changes[mode_count].arg = mask;
+  mode_changes[mode_count].arg = mask;  /* At this point 'mask' is no longer than NICKLEN + USERLEN + HOSTLEN + 3 */
   mode_changes[mode_count].id = NULL;
+  if (HasCMode(chptr, MODE_HIDEBMASKS))
+    mode_changes[mode_count].flags = CHFL_CHANOP | CHFL_HALFOP;
+  else
+    mode_changes[mode_count].flags = 0;
   mode_changes[mode_count++].dir = dir;
 }
 
@@ -681,9 +680,11 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     DLINK_FOREACH(node, chptr->invexlist.head)
     {
       const struct Ban *ban = node->data;
-      sendto_one_numeric(source_p, &me, RPL_INVEXLIST, chptr->name,
-                         ban->name, ban->user, ban->host,
-                         ban->who, ban->when);
+
+      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= CHACCESS_HALFOP)
+        sendto_one_numeric(source_p, &me, RPL_INVEXLIST, chptr->name,
+                           ban->name, ban->user, ban->host,
+                           ban->who, ban->when);
     }
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFINVEXLIST, chptr->name);
@@ -704,7 +705,7 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
     return;
 
-  char *mask = nuh_mask[*parn];
+  char *const mask = nuh_mask[*parn];
   strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
   ++(*parn);
 
@@ -726,8 +727,12 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   }
 
   mode_changes[mode_count].letter = c;
-  mode_changes[mode_count].arg = mask;
+  mode_changes[mode_count].arg = mask;  /* At this point 'mask' is no longer than NICKLEN + USERLEN + HOSTLEN + 3 */
   mode_changes[mode_count].id = NULL;
+  if (HasCMode(chptr, MODE_HIDEBMASKS))
+    mode_changes[mode_count].flags = CHFL_CHANOP | CHFL_HALFOP;
+  else
+    mode_changes[mode_count].flags = 0;
   mode_changes[mode_count++].dir = dir;
 }
 
@@ -786,6 +791,7 @@ chm_voice(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
+  mode_changes[mode_count].flags = 0;
   mode_changes[mode_count++].dir = dir;
 }
 
@@ -844,6 +850,7 @@ chm_hop(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
+  mode_changes[mode_count].flags = 0;
   mode_changes[mode_count++].dir = dir;
 }
 
@@ -902,6 +909,7 @@ chm_op(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
+  mode_changes[mode_count].flags = 0;
   mode_changes[mode_count++].dir = dir;
 }
 
@@ -940,6 +948,7 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = lstr;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
 
     chptr->mode.limit = limit;
@@ -954,6 +963,7 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
 }
@@ -991,8 +1001,9 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
         mode_changes[i].letter = 0;
 
     mode_changes[mode_count].letter = c;
-    mode_changes[mode_count].arg = chptr->mode.key;
+    mode_changes[mode_count].arg = key;
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL)
@@ -1008,6 +1019,7 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = "*";
     mode_changes[mode_count].id = NULL;
+    mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
   }
 }
@@ -1090,10 +1102,10 @@ const struct ChannelMode ModeTable[256] =
   { chm_invex,   0 },                   /* I */
   { chm_nosuch,  0 },                   /* J */
   { chm_nosuch,  0 },                   /* K */
-  { chm_nosuch,  0 },                   /* L */
+  { chm_simple_oper,  MODE_EXTLIMIT },  /* L */
   { chm_simple, MODE_MODREG},           /* M */
   { chm_nosuch,  0 },                   /* N */
-  { chm_operonly, MODE_OPERONLY},       /* O */
+  { chm_simple_oper, MODE_OPERONLY},    /* O */
   { chm_nosuch,  0 },                   /* P */
   { chm_nosuch,  0 },                   /* Q */
   { chm_simple, MODE_REGONLY},          /* R */
@@ -1131,7 +1143,7 @@ const struct ChannelMode ModeTable[256] =
   { chm_registered, MODE_REGISTERED },  /* r */
   { chm_simple,     MODE_SECRET     },  /* s */
   { chm_simple,     MODE_TOPICLIMIT },  /* t */
-  { chm_nosuch,     0               },  /* u */
+  { chm_simple,     MODE_HIDEBMASKS },  /* u */
   { chm_voice,      0               },  /* v */
   { chm_nosuch,     0               },  /* w */
   { chm_nosuch,     0               },  /* x */
@@ -1313,17 +1325,14 @@ get_channel_access(const struct Client *source_p,
 static void
 send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
 {
-  int mbl = 0, pbl = 0, arglen = 0, nc = 0, mc = 0;
-  int len = 0;
-  int dir = MODE_QUERY;
-  const char *arg = NULL;
-  char *parptr = NULL;
+  char modebuf[IRCD_BUFSIZE] = "";
+  char parabuf[IRCD_BUFSIZE] = "";
+  char *parptr = parabuf;
+  unsigned int mbl = 0, pbl = 0, arglen = 0, modecount = 0, paracount = 0;
+  unsigned int dir = MODE_QUERY;
 
-  parabuf[0] = '\0';
-  parptr = parabuf;
-
-  mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ", source_p->id,
-                 chptr->creationtime, chptr->name);
+  mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ",
+                 source_p->id, chptr->creationtime, chptr->name);
 
   /* Loop the list of modes we have */
   for (unsigned int i = 0; i < mode_count; ++i)
@@ -1331,6 +1340,7 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
     if (mode_changes[i].letter == 0)
       continue;
 
+    const char *arg;
     if (mode_changes[i].id)
       arg = mode_changes[i].id;
     else
@@ -1345,18 +1355,17 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
      * If we're creeping past the buf size, we need to send it and make
      * another line for the other modes
      */
-    if ((mc == MAXMODEPARAMS) ||
-        ((arglen + mbl + pbl + 2) > IRCD_BUFSIZE) ||
-        (pbl + arglen + BAN_FUDGE) >= MODEBUFLEN)
+    if ((paracount == MAXMODEPARAMS) ||
+        ((arglen + mbl + pbl + 2 /* +2 for /r/n */ ) > IRCD_BUFSIZE))
     {
-      if (nc)
+      if (modecount)
         sendto_server(source_p, 0, 0, "%s %s", modebuf, parabuf);
 
-      nc = 0;
-      mc = 0;
+      modecount = 0;
+      paracount = 0;
 
-      mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ", source_p->id,
-                     chptr->creationtime, chptr->name);
+      mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ",
+                     source_p->id, chptr->creationtime, chptr->name);
 
       pbl = 0;
       parabuf[0] = '\0';
@@ -1372,21 +1381,18 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
 
     modebuf[mbl++] = mode_changes[i].letter;
     modebuf[mbl] = '\0';
-    ++nc;
+    ++modecount;
 
     if (arg)
     {
-      len = sprintf(parptr, "%s ", arg);
+      int len = sprintf(parptr, (pbl == 0) ? "%s" : " %s", arg);
       pbl += len;
       parptr += len;
-      ++mc;
+      ++paracount;
     }
   }
 
-  if (pbl && parabuf[pbl - 1] == ' ')
-    parabuf[pbl - 1] = '\0';
-
-  if (nc)
+  if (modecount)
     sendto_server(source_p, 0, 0, "%s %s", modebuf, parabuf);
 }
 
@@ -1400,89 +1406,83 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
  * Side-effects: Sends the appropriate mode changes to other clients
  *               and propagates to servers.
  */
-/* ensure parabuf < MODEBUFLEN -db */
 static void
 send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
 {
-  int mbl = 0, pbl = 0, arglen = 0, nc = 0, mc = 0;
-  int len = 0;
-  int dir = MODE_QUERY;
-  const char *arg = NULL;
-  char *parptr = NULL;
+  unsigned int flags = 0;
 
-  if (IsServer(source_p))
-    mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
-                   ConfigServerHide.hide_servers) ?
-                   me.name : source_p->name, chptr->name);
-  else
-    mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
-                   source_p->username, source_p->host, chptr->name);
-
-  parabuf[0] = '\0';
-  parptr = parabuf;
-
-  for (unsigned int i = 0; i < mode_count; ++i)
+  for (unsigned int pass = 2; pass--; flags = CHFL_CHANOP | CHFL_HALFOP)
   {
-    if (mode_changes[i].letter == 0)
-      continue;
+    char modebuf[IRCD_BUFSIZE] = "";
+    char parabuf[IRCD_BUFSIZE] = "";
+    char *parptr = parabuf;
+    unsigned int mbl = 0, pbl = 0, arglen = 0, modecount = 0, paracount = 0;
+    unsigned int dir = MODE_QUERY;
 
-    arg = mode_changes[i].arg;
-    if (arg)
-      arglen = strlen(arg);
+    if (IsServer(source_p))
+      mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
+                     ConfigServerHide.hide_servers) ?
+                     me.name : source_p->name, chptr->name);
     else
-      arglen = 0;
+      mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
+                     source_p->username, source_p->host, chptr->name);
 
-    if ((mc == MAXMODEPARAMS) ||
-        ((arglen + mbl + pbl + 2) > IRCD_BUFSIZE) ||
-        ((arglen + pbl + BAN_FUDGE) >= MODEBUFLEN))
+    for (unsigned int i = 0; i < mode_count; ++i)
     {
-      if (mbl && modebuf[mbl - 1] == '-')
-        modebuf[mbl - 1] = '\0';
+      if (mode_changes[i].letter == 0 || mode_changes[i].flags != flags)
+        continue;
 
-      if (nc)
-        sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
-
-      nc = 0;
-      mc = 0;
-
-      if (IsServer(source_p))
-        mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
-                       ConfigServerHide.hide_servers) ?
-                       me.name : source_p->name, chptr->name);
+      const char *arg = mode_changes[i].arg;
+      if (arg)
+        arglen = strlen(arg);
       else
-        mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
-                       source_p->username, source_p->host, chptr->name);
+        arglen = 0;
 
-      pbl = 0;
-      parabuf[0] = '\0';
-      parptr = parabuf;
-      dir = MODE_QUERY;
+      if ((paracount == MAXMODEPARAMS) ||
+          ((arglen + mbl + pbl + 2 /* +2 for /r/n */ ) > IRCD_BUFSIZE))
+      {
+        if (modecount)
+          sendto_channel_local(NULL, chptr, flags, 0, 0, "%s %s", modebuf, parabuf);
+
+        modecount = 0;
+        paracount = 0;
+
+        if (IsServer(source_p))
+          mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
+                         ConfigServerHide.hide_servers) ?
+                         me.name : source_p->name, chptr->name);
+        else
+          mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
+                         source_p->username, source_p->host, chptr->name);
+
+        pbl = 0;
+        parabuf[0] = '\0';
+        parptr = parabuf;
+        dir = MODE_QUERY;
+      }
+
+      if (dir != mode_changes[i].dir)
+      {
+        modebuf[mbl++] = (mode_changes[i].dir == MODE_ADD) ? '+' : '-';
+        dir = mode_changes[i].dir;
+      }
+
+      modebuf[mbl++] = mode_changes[i].letter;
+      modebuf[mbl] = '\0';
+      ++modecount;
+
+      if (arg)
+      {
+        int len = sprintf(parptr, (pbl == 0) ? "%s" : " %s", arg);
+        pbl += len;
+        parptr += len;
+        ++paracount;
+      }
     }
 
-    if (dir != mode_changes[i].dir)
-    {
-      modebuf[mbl++] = (mode_changes[i].dir == MODE_ADD) ? '+' : '-';
-      dir = mode_changes[i].dir;
-    }
-
-    modebuf[mbl++] = mode_changes[i].letter;
-    modebuf[mbl] = '\0';
-    ++nc;
-
-    if (arg)
-    {
-      len = sprintf(parptr, "%s ", arg);
-      pbl += len;
-      parptr += len;
-      ++mc;
-    }
+    if (modecount)
+      sendto_channel_local(NULL, chptr, flags, 0, 0, "%s %s", modebuf, parabuf);
   }
-
-  if (pbl && parabuf[pbl - 1] == ' ')
-    parabuf[pbl - 1] = '\0';
-
-  if (nc)
-    sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
 }
 
 /*
