@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.c
  * \brief Controls clients.
- * \version $Id: client.c 7871 2016-11-09 20:13:07Z michael $
+ * \version $Id: client.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -82,7 +82,7 @@ static dlink_node *eac_next;  /* next aborted client to exit */
  *                      'from'). ('from' is a local client!!).
  */
 struct Client *
-make_client(struct Client *from)
+client_make(struct Client *from)
 {
   struct Client *const client_p = mp_pool_get(client_pool);
 
@@ -111,14 +111,14 @@ make_client(struct Client *from)
 }
 
 /*
- * free_client
+ * client_free
  *
  * inputs	- pointer to client
  * output	- NONE
  * side effects	- client pointed to has its memory freed
  */
 static void
-free_client(struct Client *client_p)
+client_free(struct Client *client_p)
 {
   assert(client_p != &me);
   assert(client_p->hnext == client_p);
@@ -242,12 +242,12 @@ check_pings_list(dlink_list *list)
           {
             sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                                  "No response from %s, closing link",
-                                 get_client_name(client_p, SHOW_IP));
+                                 client_get_name(client_p, SHOW_IP));
             sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                                  "No response from %s, closing link",
-                                 get_client_name(client_p, MASK_IP));
+                                 client_get_name(client_p, MASK_IP));
             ilog(LOG_TYPE_IRCD, "No response from %s, closing link",
-                 get_client_name(client_p, SHOW_IP));
+                 client_get_name(client_p, SHOW_IP));
           }
 
           snprintf(buf, sizeof(buf), "Ping timeout: %ji seconds",
@@ -397,7 +397,7 @@ conf_try_ban(struct Client *client_p, int type, const char *reason)
       {
         sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                              "KLINE over-ruled for %s, client is kline_exempt",
-                             get_client_name(client_p, HIDE_IP));
+                             client_get_name(client_p, HIDE_IP));
         return;
       }
 
@@ -414,7 +414,7 @@ conf_try_ban(struct Client *client_p, int type, const char *reason)
       {
         sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                              "XLINE over-ruled for %s, client is xline_exempt",
-                             get_client_name(client_p, HIDE_IP));
+                             client_get_name(client_p, HIDE_IP));
         return;
       }
 
@@ -426,7 +426,7 @@ conf_try_ban(struct Client *client_p, int type, const char *reason)
   }
 
   sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "%c-line active for %s",
-                       ban_type, get_client_name(client_p, HIDE_IP));
+                       ban_type, client_get_name(client_p, HIDE_IP));
 
   if (IsClient(client_p))
     sendto_one_numeric(client_p, &me, ERR_YOUREBANNEDCREEP, reason);
@@ -434,31 +434,6 @@ conf_try_ban(struct Client *client_p, int type, const char *reason)
   exit_client(client_p, reason);
 }
 
-/* update_client_exit_stats()
- *
- * input	- pointer to client
- * output	- NONE
- * side effects	-
- */
-static void
-update_client_exit_stats(struct Client *client_p)
-{
-  if (IsClient(client_p))
-  {
-    assert(Count.total > 0);
-
-    --Count.total;
-    if (HasUMode(client_p, UMODE_OPER))
-      --Count.oper;
-    if (HasUMode(client_p, UMODE_INVISIBLE))
-      --Count.invisi;
-  }
-  else if (IsServer(client_p))
-    sendto_realops_flags(UMODE_EXTERNAL, L_ALL, SEND_NOTICE,
-                         "Server %s split from %s",
-                         client_p->name, client_p->servptr->name);
-}
-
 /* find_person()
  *
  * inputs	- pointer to name
@@ -505,7 +480,7 @@ find_chasing(struct Client *source_p, const char *name)
 }
 
 /*
- * get_client_name -  Return the name of the client
+ * client_get_name -  Return the name of the client
  *    for various tracking and
  *      admin purposes. The main purpose of this function is to
  *      return the "socket host" name of the client, if that
@@ -523,7 +498,7 @@ find_chasing(struct Client *source_p, const char *name)
  *        to modify what it points!!!
  */
 const char *
-get_client_name(const struct Client *client_p, enum addr_mask_type type)
+client_get_name(const struct Client *client_p, enum addr_mask_type type)
 {
   static char buf[HOSTLEN * 2 + USERLEN + 4];  /* +4 for [,@,],\0 */
 
@@ -566,11 +541,11 @@ get_client_name(const struct Client *client_p, enum addr_mask_type type)
 void
 free_exited_clients(void)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, dead_list.head)
   {
-    free_client(node->data);
+    client_free(node->data);
     dlinkDelete(node, &dead_list);
     free_dlink_node(node);
   }
@@ -585,13 +560,18 @@ free_exited_clients(void)
 static void
 exit_one_client(struct Client *source_p, const char *comment)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   assert(!IsMe(source_p));
   assert(source_p != &me);
 
   if (IsClient(source_p))
   {
+    if (HasUMode(source_p, UMODE_OPER))
+      --Count.oper;
+    if (HasUMode(source_p, UMODE_INVISIBLE))
+      --Count.invisi;
+
     dlinkDelete(&source_p->lnode, &source_p->servptr->serv->client_list);
     dlinkDelete(&source_p->node, &global_client_list);
 
@@ -623,11 +603,12 @@ exit_one_client(struct Client *source_p, const char *comment)
   }
   else if (IsServer(source_p))
   {
-    dlinkDelete(&source_p->lnode, &source_p->servptr->serv->server_list);
-    dlinkDelete(&source_p->node, &global_client_list);
+    sendto_realops_flags(UMODE_EXTERNAL, L_ALL, SEND_NOTICE,
+                         "Server %s split from %s",
+                         source_p->name, source_p->servptr->name);
 
-    if ((node = dlinkFindDelete(&global_server_list, source_p)))
-      free_dlink_node(node);
+    dlinkDelete(&source_p->lnode, &source_p->servptr->serv->server_list);
+    dlinkDelete(&source_p->node, &global_server_list);
   }
 
   /* Remove source_p from the client lists */
@@ -640,8 +621,6 @@ exit_one_client(struct Client *source_p, const char *comment)
   if (HasFlag(source_p, FLAGS_USERHOST))
     userhost_del(source_p->sockhost, !MyConnect(source_p));
 
-  update_client_exit_stats(source_p);
-
   /* Check to see if the client isn't already on the dead list */
   assert(dlinkFind(&dead_list, source_p) == NULL);
 
@@ -659,7 +638,7 @@ exit_one_client(struct Client *source_p, const char *comment)
 static void
 recurse_remove_clients(struct Client *source_p, const char *comment)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, source_p->serv->client_list.head)
     exit_one_client(node->data, comment);
@@ -691,15 +670,15 @@ recurse_remove_clients(struct Client *source_p, const char *comment)
 void
 exit_client(struct Client *source_p, const char *comment)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   assert(!IsMe(source_p));
   assert(source_p != &me);
 
   if (MyConnect(source_p))
   {
-    /* DO NOT REMOVE. exit_client can be called twice after a failed
-     * read/write.
+    /*
+     * DO NOT REMOVE. exit_client can be called twice after a failed read/write.
      */
     if (HasFlag(source_p, FLAGS_CLOSING))
       return;
@@ -712,14 +691,10 @@ exit_client(struct Client *source_p, const char *comment)
       ipcache_remove_address(&source_p->connection->ip);
     }
 
-    delete_auth(&source_p->connection->auth);
+    auth_delete(&source_p->connection->auth);
 
     if (IsClient(source_p))
     {
-      assert(Count.local > 0);
-
-      --Count.local;
-
       if (HasUMode(source_p, UMODE_OPER))
         if ((node = dlinkFindDelete(&oper_list, source_p)))
           free_dlink_node(node);
@@ -747,10 +722,6 @@ exit_client(struct Client *source_p, const char *comment)
     }
     else if (IsServer(source_p))
     {
-      assert(Count.myserver > 0);
-
-      --Count.myserver;
-
       assert(dlinkFind(&local_server_list, source_p));
       dlinkDelete(&source_p->connection->lclient_node, &local_server_list);
     }
@@ -884,22 +855,22 @@ dead_link_on_read(struct Client *client_p, int error)
       /* Admins get the real IP */
       sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                            "Server %s closed the connection",
-                           get_client_name(client_p, SHOW_IP));
+                           client_get_name(client_p, SHOW_IP));
 
       /* Opers get a masked IP */
       sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                            "Server %s closed the connection",
-                           get_client_name(client_p, MASK_IP));
+                           client_get_name(client_p, MASK_IP));
 
       ilog(LOG_TYPE_IRCD, "Server %s closed the connection",
-           get_client_name(client_p, SHOW_IP));
+           client_get_name(client_p, SHOW_IP));
     }
     else
     {
       report_error(L_ADMIN, "Lost connection to %s: %s",
-                   get_client_name(client_p, SHOW_IP), current_error);
+                   client_get_name(client_p, SHOW_IP), current_error);
       report_error(L_OPER, "Lost connection to %s: %s",
-                   get_client_name(client_p, MASK_IP), current_error);
+                   client_get_name(client_p, MASK_IP), current_error);
     }
 
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
@@ -976,7 +947,7 @@ find_accept(const char *nick, const char *user,
             const char *host, struct Client *client_p,
             int (*cmpfunc)(const char *, const char *))
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, client_p->connection->acceptlist.head)
   {
@@ -1002,7 +973,7 @@ int
 accept_message(struct Client *source,
                struct Client *target)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   if (HasFlag(source, FLAGS_SERVICE) ||
       (HasUMode(source, UMODE_OPER) && ConfigGeneral.opers_bypass_callerid))
@@ -1029,7 +1000,7 @@ accept_message(struct Client *source,
 void
 del_all_accepts(struct Client *client_p)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, client_p->connection->acceptlist.head)
     del_accept(node->data, client_p);
@@ -1040,8 +1011,6 @@ client_get_idle_time(const struct Client *source_p,
                      const struct Client *target_p)
 {
   unsigned int idle = 0;
-  unsigned int min_idle = 0;
-  unsigned int max_idle = 0;
   const struct ClassItem *const class = get_class_ptr(&target_p->connection->confs);
 
   if (!(class->flags & CLASS_FLAGS_FAKE_IDLE) || target_p == source_p)
@@ -1051,8 +1020,8 @@ client_get_idle_time(const struct Client *source_p,
       !(class->flags & CLASS_FLAGS_HIDE_IDLE_FROM_OPERS))
     return CurrentTime - target_p->connection->last_privmsg;
 
-  min_idle = class->min_idle;
-  max_idle = class->max_idle;
+  const unsigned int min_idle = class->min_idle;
+  const unsigned int max_idle = class->max_idle;
 
   if (min_idle == max_idle)
     return min_idle;
