@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id: conf.c 7859 2016-11-08 20:09:29Z michael $
+ * \version $Id: conf.c 8045 2017-03-18 18:05:41Z michael $
  */
 
 #include "stdinc.h"
@@ -340,10 +340,10 @@ check_client(struct Client *source_p)
     case TOO_MANY:
       sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
                            "Too many on IP for %s (%s).",
-                           get_client_name(source_p, SHOW_IP),
+                           client_get_name(source_p, SHOW_IP),
                            source_p->sockhost);
       ilog(LOG_TYPE_IRCD, "Too many connections on IP from %s.",
-           get_client_name(source_p, SHOW_IP));
+           client_get_name(source_p, SHOW_IP));
       ++ServerStats.is_ref;
       exit_client(source_p, "No more connections allowed on that IP");
       break;
@@ -351,10 +351,10 @@ check_client(struct Client *source_p)
     case I_LINE_FULL:
       sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
                            "auth {} block is full for %s (%s).",
-                           get_client_name(source_p, SHOW_IP),
+                           client_get_name(source_p, SHOW_IP),
                            source_p->sockhost);
       ilog(LOG_TYPE_IRCD, "Too many connections from %s.",
-           get_client_name(source_p, SHOW_IP));
+           client_get_name(source_p, SHOW_IP));
       ++ServerStats.is_ref;
       exit_client(source_p, "No more connections allowed in your connection class");
       break;
@@ -364,11 +364,11 @@ check_client(struct Client *source_p)
       /*       a purely cosmetical change */
       sendto_realops_flags(UMODE_UNAUTH, L_ALL, SEND_NOTICE,
                            "Unauthorized client connection from %s on [%s/%u].",
-                           get_client_name(source_p, SHOW_IP),
+                           client_get_name(source_p, SHOW_IP),
                            source_p->connection->listener->name,
                            source_p->connection->listener->port);
       ilog(LOG_TYPE_IRCD, "Unauthorized client connection from %s on [%s/%u].",
-           get_client_name(source_p, SHOW_IP),
+           client_get_name(source_p, SHOW_IP),
            source_p->connection->listener->name,
            source_p->connection->listener->port);
 
@@ -645,7 +645,8 @@ set_default_conf(void)
   ConfigChannel.knock_delay_channel = 60;
   ConfigChannel.max_channels = 25;
   ConfigChannel.max_invites = 20;
-  ConfigChannel.max_bans = 25;
+  ConfigChannel.max_bans = 100;
+  ConfigChannel.max_bans_large = 500;
   ConfigChannel.default_join_flood_count = 18;
   ConfigChannel.default_join_flood_time = 6;
 
@@ -694,7 +695,7 @@ set_default_conf(void)
   ConfigGeneral.stats_P_oper_only = 0;
   ConfigGeneral.stats_u_oper_only = 0;
   ConfigGeneral.caller_id_wait = 60;
-  ConfigGeneral.opers_bypass_callerid = 0;
+  ConfigGeneral.opers_bypass_callerid = 1;
   ConfigGeneral.pace_wait = 10;
   ConfigGeneral.pace_wait_simple = 1;
   ConfigGeneral.short_motd = 0;
@@ -1145,7 +1146,7 @@ read_conf_files(int cold)
   snprintf(chanlimit, sizeof(chanlimit), "#:%u",
            ConfigChannel.max_channels);
   isupport_add("CHANLIMIT", chanlimit, -1);
-  snprintf(chanmodes, sizeof(chanmodes), "%s", "beI,k,l,cimnprstCMORST");
+  snprintf(chanmodes, sizeof(chanmodes), "%s", "beI,k,l,cimnprstuCLMORST");
   isupport_add("CHANNELLEN", NULL, CHANNELLEN);
   isupport_add("TOPICLEN", NULL, ConfigServerInfo.max_topic_length);
   isupport_add("CHANMODES", chanmodes, -1);
