@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2016 ircd-hybrid development team
+ *  Copyright (c) 2014-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_pseudo.c
  * \brief Handles with pseudo commands/service aliases.
- * \version $Id: conf_pseudo.c 7293 2016-02-09 19:02:08Z michael $
+ * \version $Id: conf_pseudo.c 7925 2016-12-31 13:57:24Z michael $
  */
 
 #include "stdinc.h"
@@ -51,6 +51,13 @@ struct PseudoItem
 
 static dlink_list pseudo_list;
 
+
+const dlink_list *
+pseudo_get_list(void)
+{
+  return &pseudo_list;
+}
+
 static int
 m_pseudo(struct Client *source_p, int parc, char *parv[])
 {
