@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2016 ircd-hybrid development team
+ *  Copyright (c) 2001-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_resv.c
  * \brief Functions to reserve(jupe) a nick/channel.
- * \version $Id: conf_resv.c 7686 2016-08-18 17:32:04Z michael $
+ * \version $Id: conf_resv.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "stdinc.h"
@@ -151,8 +151,8 @@ resv_make(const char *mask, const char *reason, const dlink_list *elist)
 struct ResvItem *
 resv_find(const char *name, int (*compare)(const char *, const char *))
 {
-  dlink_node *node = NULL;
-  dlink_list *list = NULL;
+  dlink_node *node;
+  dlink_list *list;
 
   if (IsChanPrefix(*name))
     list = &resv_chan_list;
@@ -218,7 +218,7 @@ resv_clear(void)
 
   for (dlink_list **list = tab; *list; ++list)
   {
-    dlink_node *node = NULL, *node_next = NULL;
+    dlink_node *node, *node_next;
 
     DLINK_FOREACH_SAFE(node, node_next, (*list)->head)
     {
@@ -237,7 +237,7 @@ resv_expire(void)
 
   for (dlink_list **list = tab; *list; ++list)
   {
-    dlink_node *node = NULL, *node_next = NULL;
+    dlink_node *node, *node_next;
 
     DLINK_FOREACH_SAFE(node, node_next, (*list)->head)
     {
