@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007-2012, The Tor Project, Inc.
- * Copyright (c) 2012-2016 ircd-hybrid development team
+ * Copyright (c) 2012-2017 ircd-hybrid development team
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -33,7 +33,7 @@
 
 /*! \file mempool.c
  * \brief A pooling allocator
- * \version $Id: mempool.c 7500 2016-03-22 19:48:49Z michael $
+ * \version $Id: mempool.c 7925 2016-12-31 13:57:24Z michael $
  */
 
 #include "stdinc.h"
@@ -221,7 +221,7 @@ struct mp_chunk_t
   char mem[]; /**< Storage for this chunk. */
 };
 
-static mp_pool_t *mp_allocated_pools = NULL;
+static mp_pool_t *mp_allocated_pools;
 
 /** Number of extra bytes needed beyond mem_size to allocate a chunk. */
 #define CHUNK_OVERHEAD offsetof(mp_chunk_t, mem[0])
