@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_misc.c
  * \brief Yet another miscellaneous functions file.
- * \version $Id: misc.c 7667 2016-07-20 17:09:36Z michael $
+ * \version $Id: misc.c 7940 2017-01-27 15:04:09Z michael $
  */
 
 #include "stdinc.h"
@@ -41,7 +41,7 @@ date(uintmax_t lclock)
 
   if (lclock_last != lclock)
   {
-    lclock_last = lclock;
+    lclock_last = lclock;  /* Cache value to avoid repetitive strftime() calls. */
     strftime(buf, sizeof(buf), "%A %B %-e %Y -- %T %z", localtime((time_t *)&lclock));
   }
 
@@ -59,7 +59,7 @@ date_iso8601(uintmax_t lclock)
 
   if (lclock_last != lclock)
   {
-    lclock_last = lclock;
+    lclock_last = lclock;  /* Cache value to avoid repetitive strftime() calls. */
     strftime(buf, sizeof(buf), "%FT%T%z", localtime((time_t *)&lclock));
   }
 
@@ -89,7 +89,7 @@ date_ctime(uintmax_t lclock)
 
   if (lclock_last != lclock)
   {
-    lclock_last = lclock;
+    lclock_last = lclock;  /* Cache value to avoid repetitive strftime() calls. */
     strftime(buf, sizeof(buf), "%a %b %-e %T %Y", localtime((time_t *)&lclock));
   }
 
