@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2016 ircd-hybrid development team
+ *  Copyright (c) 2000-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file modules.c
  * \brief A module loader.
- * \version $Id: modules.c 7667 2016-07-20 17:09:36Z michael $
+ * \version $Id: modules.c 8058 2017-03-23 16:13:10Z michael $
  */
 
 #include "ltdl.h"
@@ -202,7 +202,7 @@ modules_init(void)
 static struct module_path *
 mod_find_path(const char *path)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, modules_path.head)
   {
@@ -287,7 +287,7 @@ modules_conf_clear(void)
 struct module *
 findmodule_byname(const char *name)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, modules_list.head)
   {
@@ -342,7 +342,7 @@ load_all_modules(int warn)
 void
 load_conf_modules(void)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, modules_conf.head)
   {
@@ -388,7 +388,7 @@ load_core_modules(int warn)
 int
 load_one_module(const char *name)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
   char path[HYB_PATH_MAX + 1];
   struct stat statbuf;
 
