@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd.c
  * \brief Network functions.
- * \version $Id: s_bsd.c 7667 2016-07-20 17:09:36Z michael $
+ * \version $Id: s_bsd.c 7956 2017-03-05 11:52:53Z michael $
  */
 
 #include "stdinc.h"
@@ -248,7 +248,7 @@ ssl_handshake(fde_t *fd, void *data)
     ilog(LOG_TYPE_IRCD, "Client %s!%s@%s gave bad TLS client certificate",
          client_p->name, client_p->username, client_p->host);
 
-  start_auth(client_p);
+  auth_start(client_p);
 }
 
 /*
@@ -261,7 +261,7 @@ ssl_handshake(fde_t *fd, void *data)
 void
 add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
 {
-  struct Client *client_p = make_client(NULL);
+  struct Client *client_p = client_make(NULL);
 
   fd_open(&client_p->connection->fd, fd, 1,
           (listener->flags & LISTENER_SSL) ?
@@ -319,7 +319,7 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
     ssl_handshake(NULL, client_p);
   }
   else
-    start_auth(client_p);
+    auth_start(client_p);
 }
 
 /*
