@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.c
  * \brief Functions for sending messages.
- * \version $Id: send.c 7667 2016-07-20 17:09:36Z michael $
+ * \version $Id: send.c 8035 2017-03-17 17:49:11Z michael $
  */
 
 #include "stdinc.h"
@@ -91,7 +91,7 @@ send_message(struct Client *to, struct dbuf_block *buf)
     if (IsServer(to))
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "Max SendQ limit exceeded for %s: %zu > %u",
-                           get_client_name(to, HIDE_IP),
+                           client_get_name(to, HIDE_IP),
                            (dbuf_length(&to->connection->buf_sendq) + buf->size),
                            get_sendq(&to->connection->confs));
 
@@ -263,15 +263,15 @@ void
 sendto_one(struct Client *to, const char *pattern, ...)
 {
   va_list args;
-  struct dbuf_block *buffer = NULL;
 
   if (IsDead(to->from))
     return;  /* This socket has already been marked as dead */
 
-  buffer = dbuf_alloc();
-
   va_start(args, pattern);
+
+  struct dbuf_block *buffer = dbuf_alloc();
   send_format(buffer, pattern, args);
+
   va_end(args);
 
   send_message(to->from, buffer);
@@ -282,20 +282,17 @@ sendto_one(struct Client *to, const char *pattern, ...)
 void
 sendto_one_numeric(struct Client *to, const struct Client *from, enum irc_numerics numeric, ...)
 {
-  struct dbuf_block *buffer = NULL;
-  const char *dest = NULL, *numstr = NULL;
   va_list args;
+  const char *numstr = NULL;
 
   if (IsDead(to->from))
     return;
 
-  dest = ID_or_name(to, to);
-
+  const char *dest = ID_or_name(to, to);
   if (EmptyString(dest))
     dest = "*";
 
-  buffer = dbuf_alloc();
-
+  struct dbuf_block *buffer = dbuf_alloc();
   dbuf_put_fmt(buffer, ":%s %03d %s ", ID_or_name(from, to), numeric & ~SND_EXPLICIT, dest);
 
   va_start(args, numeric);
@@ -316,20 +313,16 @@ sendto_one_numeric(struct Client *to, const struct Client *from, enum irc_numeri
 void
 sendto_one_notice(struct Client *to, const struct Client *from, const char *pattern, ...)
 {
-  struct dbuf_block *buffer = NULL;
-  const char *dest = NULL;
   va_list args;
 
   if (IsDead(to->from))
     return;
 
-  dest = ID_or_name(to, to);
-
+  const char *dest = ID_or_name(to, to);
   if (EmptyString(dest))
     dest = "*";
 
-  buffer = dbuf_alloc();
-
+  struct dbuf_block *buffer = dbuf_alloc();
   dbuf_put_fmt(buffer, ":%s NOTICE %s ", ID_or_name(from, to), dest);
 
   va_start(args, pattern);
@@ -387,13 +380,18 @@ sendto_channel_butone(struct Client *one, const struct Client *from,
 
     assert(IsClient(target_p));
 
-    if (IsDefunct(target_p) || HasUMode(target_p, UMODE_DEAF) ||
-        (one && target_p->from == one->from))
+    if (IsDefunct(target_p->from))
+      continue;
+
+    if (one && (target_p->from == one->from))
       continue;
 
     if (type && (member->flags & type) == 0)
       continue;
 
+    if (HasUMode(target_p, UMODE_DEAF))
+      continue;
+
     if (MyConnect(target_p))
       send_message(target_p, local_buf);
     else if (target_p->from->connection->serial != current_serial)
@@ -431,11 +429,13 @@ sendto_server(const struct Client *one,
               const char *format, ...)
 {
   va_list args;
-  dlink_node *node = NULL;
-  struct dbuf_block *buffer = dbuf_alloc();
+  dlink_node *node;
 
   va_start(args, format);
+
+  struct dbuf_block *buffer = dbuf_alloc();
   send_format(buffer, format, args);
+
   va_end(args);
 
   DLINK_FOREACH(node, local_server_list.head)
@@ -732,13 +732,11 @@ sendto_anywhere(struct Client *to, const struct Client *from,
                 const char *pattern, ...)
 {
   va_list args;
-  struct dbuf_block *buffer = NULL;
 
   if (IsDead(to->from))
     return;
 
-  buffer = dbuf_alloc();
-
+  struct dbuf_block *buffer = dbuf_alloc();
   if (MyClient(to) && IsClient(from))
     dbuf_put_fmt(buffer, ":%s!%s@%s %s %s ", from->name, from->username,
                  from->host, command, to->name);
@@ -769,15 +767,10 @@ sendto_anywhere(struct Client *to, const struct Client *from,
 void
 sendto_realops_flags(unsigned int flags, int level, int type, const char *pattern, ...)
 {
-  const char *ntype = NULL;
-  dlink_node *node = NULL;
-  char nbuf[IRCD_BUFSIZE] = "";
+  const char *ntype = "???";
+  dlink_node *node;
   va_list args;
 
-  va_start(args, pattern);
-  vsnprintf(nbuf, sizeof(nbuf), pattern, args);
-  va_end(args);
-
   switch (type)
   {
     case SEND_NOTICE:
@@ -793,6 +786,13 @@ sendto_realops_flags(unsigned int flags, int level, int type, const char *patter
       assert(0);
   }
 
+  struct dbuf_block *buffer = dbuf_alloc();
+  dbuf_put_fmt(buffer, ":%s NOTICE * :*** %s -- ", me.name, ntype); 
+
+  va_start(args, pattern);
+  send_format(buffer, pattern, args);
+  va_end(args);
+
   DLINK_FOREACH(node, oper_list.head)
   {
     struct Client *client_p = node->data;
@@ -806,9 +806,11 @@ sendto_realops_flags(unsigned int flags, int level, int type, const char *patter
         ((level == L_OPER) && HasUMode(client_p, UMODE_ADMIN)))
       continue;
 
-    if (HasUMode(client_p, flags))
-      sendto_one_notice(client_p, &me, ":*** %s -- %s", ntype, nbuf);
+    if (HasUMode(client_p, flags) && !IsDead(client_p))
+      send_message(client_p, buffer);
   }
+
+  dbuf_ref_free(buffer);
 }
 
 /* ts_warn()
@@ -867,7 +869,7 @@ sendto_wallops_flags(unsigned int flags, const struct Client *source_p,
     struct Client *client_p = node->data;
     assert(client_p->umodes & UMODE_OPER);
 
-    if (HasUMode(client_p, flags) && !IsDefunct(client_p))
+    if (HasUMode(client_p, flags) && !IsDead(client_p))
       send_message(client_p, buffer);
   }
 
