@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_serv.c
  * \brief Server related functions.
- * \version $Id: server.c 7686 2016-08-18 17:32:04Z michael $
+ * \version $Id: server.c 7996 2017-03-14 13:17:39Z michael $
  */
 
 #include "stdinc.h"
@@ -59,7 +59,7 @@ void
 write_links_file(void *unused)
 {
   FILE *file = NULL;
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
   char buff[IRCD_BUFSIZE] = "";
 
   if (EmptyString(ConfigServerHide.flatten_links_file))
@@ -139,7 +139,7 @@ read_links_file(void)
   fclose(file);
 }
 
-/* hunt_server()
+/* server_hunt()
  *      Do the basic thing in delivering the message (command)
  *      across the relays to the specific server (server) for
  *      actions.
@@ -158,30 +158,35 @@ read_links_file(void)
  *
  *      returns: (see #defines)
  */
-int
-hunt_server(struct Client *source_p, const char *command,
+const struct server_hunt *
+server_hunt(struct Client *source_p, const char *command,
             const int server, const int parc, char *parv[])
 {
-  struct Client *target_p = NULL;
-  dlink_node *node = NULL;
+  static struct server_hunt hunt;
+  struct server_hunt *const h = &hunt;
+  dlink_node *node;
 
   /* Assume it's me, if no server */
   if (parc <= server || EmptyString(parv[server]))
-    return HUNTED_ISME;
+  {
+    h->target_p = &me;
+    h->ret = HUNTED_ISME;
+    return h;
+  }
 
-  if ((target_p = find_person(source_p, parv[server])) == NULL)
-    target_p = hash_find_server(parv[server]);
+  if ((h->target_p = find_person(source_p, parv[server])) == NULL)
+    h->target_p = hash_find_server(parv[server]);
 
   /*
    * These are to pickup matches that would cause the following
    * message to go in the wrong direction while doing quick fast
    * non-matching lookups.
    */
-  if (target_p)
-    if (target_p->from == source_p->from && !MyConnect(target_p))
-      target_p = NULL;
+  if (h->target_p)
+    if (h->target_p->from == source_p->from && !MyConnect(h->target_p))
+      h->target_p = NULL;
 
-  if (!target_p && has_wildcards(parv[server]))
+  if (!h->target_p && has_wildcards(parv[server]))
   {
     DLINK_FOREACH(node, global_server_list.head)
     {
@@ -193,45 +198,50 @@ hunt_server(struct Client *source_p, const char *command,
         if (tmp->from == source_p->from && !MyConnect(tmp))
           continue;
 
-        target_p = node->data;
+        h->target_p = tmp;
         break;
       }
     }
 
-    if (!target_p)
+    if (!h->target_p)
     {
       DLINK_FOREACH(node, global_client_list.head)
       {
         struct Client *tmp = node->data;
 
-        assert(IsMe(tmp) || IsServer(tmp) || IsClient(tmp));
+        assert(IsClient(tmp));
         if (!match(parv[server], tmp->name))
         {
           if (tmp->from == source_p->from && !MyConnect(tmp))
             continue;
 
-          target_p = node->data;
+          h->target_p = tmp;
           break;
         }
       }
     }
   }
 
-  if (target_p)
+  if (h->target_p)
   {
-    assert(IsMe(target_p) || IsServer(target_p) || IsClient(target_p));
-    if (IsMe(target_p) || MyClient(target_p))
-      return HUNTED_ISME;
+    assert(IsMe(h->target_p) || IsServer(h->target_p) || IsClient(h->target_p));
+    if (IsMe(h->target_p) || MyClient(h->target_p))
+    {
+      h->ret = HUNTED_ISME;
+      return h;
+    }
 
-    parv[server] = target_p->id;
-    sendto_one(target_p, command, source_p->id,
+    parv[server] = h->target_p->id;
+    sendto_one(h->target_p, command, source_p->id,
                parv[1], parv[2], parv[3], parv[4],
                parv[5], parv[6], parv[7], parv[8]);
-    return HUNTED_PASS;
+    h->ret = HUNTED_PASS;
+    return h;
   }
 
   sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, parv[server]);
-  return HUNTED_NOSUCH;
+  h->ret = HUNTED_NOSUCH;
+  return h;
 }
 
 /* try_connections()
@@ -247,7 +257,7 @@ hunt_server(struct Client *source_p, const char *command,
 void
 try_connections(void *unused)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   if (GlobalSetOptions.autoconn == 0)
     return;
@@ -257,6 +267,7 @@ try_connections(void *unused)
     struct MaskItem *conf = node->data;
 
     assert(conf->type == CONF_SERVER);
+    assert(conf->class);
 
     /* Also when already connecting! (update holdtimes) --SRB */
     if (!conf->port || !IsConfAllowAutoConn(conf))
@@ -272,8 +283,6 @@ try_connections(void *unused)
     if (conf->until > CurrentTime)
       continue;
 
-    assert(conf->class);
-
     conf->until = CurrentTime + conf->class->con_freq;
 
     /*
@@ -338,69 +347,6 @@ valid_servname(const char *name)
   return dots && (p - name) <= HOSTLEN;
 }
 
-int
-check_server(const char *name, struct Client *client_p)
-{
-  dlink_node *node = NULL;
-  struct MaskItem *server_conf = NULL;
-  int error = -1;
-
-  assert(client_p);
-
-  /* Loop through looking for all possible connect items that might work */
-  DLINK_FOREACH(node, connect_items.head)
-  {
-    struct MaskItem *conf = node->data;
-
-    if (irccmp(name, conf->name))
-      continue;
-
-    error = -3;
-
-    if (!irccmp(conf->host, client_p->host) ||
-        !irccmp(conf->host, client_p->sockhost))
-    {
-      error = -2;
-
-      if (!match_conf_password(client_p->connection->password, conf))
-        return -2;
-
-      if (!EmptyString(conf->certfp))
-        if (EmptyString(client_p->certfp) || strcasecmp(client_p->certfp, conf->certfp))
-          return -4;
-
-      server_conf = conf;
-    }
-  }
-
-  if (server_conf == NULL)
-    return error;
-
-  attach_conf(client_p, server_conf);
-
-  switch (server_conf->aftype)
-  {
-    case AF_INET6:
-    {
-      const struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)&server_conf->addr;
-
-      if (IN6_IS_ADDR_UNSPECIFIED(&v6->sin6_addr))
-        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
-      break;
-    }
-    case AF_INET:
-    {
-      const struct sockaddr_in *v4 = (struct sockaddr_in *)&server_conf->addr;
-
-      if (v4->sin_addr.s_addr == INADDR_NONE)
-        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
-      break;
-    }
-  }
-
-  return 0;
-}
-
 /* server_capab_init()
  *
  * inputs       - none
@@ -445,7 +391,7 @@ add_capability(const char *name, unsigned int flag)
 void
 delete_capability(const char *name)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, server_capabilities_list.head)
   {
@@ -593,18 +539,18 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Server %s already present from %s",
-                         conf->name, get_client_name(client_p, SHOW_IP));
+                         conf->name, client_get_name(client_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Server %s already present from %s",
-                         conf->name, get_client_name(client_p, MASK_IP));
+                         conf->name, client_get_name(client_p, MASK_IP));
     if (by && IsClient(by) && !MyClient(by))
       sendto_one_notice(by, &me, ":Server %s already present from %s",
-                        conf->name, get_client_name(client_p, MASK_IP));
+                        conf->name, client_get_name(client_p, MASK_IP));
     return 0;
   }
 
   /* Create a local client */
-  client_p = make_client(NULL);
+  client_p = client_make(NULL);
 
   /* Copy in the server, hostname, fd */
   strlcpy(client_p->name, conf->name, sizeof(client_p->name));
@@ -749,9 +695,9 @@ finish_ssl_server_handshake(struct Client *client_p)
   if (!conf)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-                         "Lost connect{} block for %s", get_client_name(client_p, SHOW_IP));
+                         "Lost connect{} block for %s", client_get_name(client_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-                         "Lost connect{} block for %s", get_client_name(client_p, MASK_IP));
+                         "Lost connect{} block for %s", client_get_name(client_p, MASK_IP));
 
     exit_client(client_p, "Lost connect{} block");
     return;
@@ -772,9 +718,9 @@ finish_ssl_server_handshake(struct Client *client_p)
   if (IsDead(client_p))
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-                         "%s went dead during handshake", get_client_name(client_p, SHOW_IP));
+                         "%s went dead during handshake", client_get_name(client_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-                         "%s went dead during handshake", get_client_name(client_p, MASK_IP));
+                         "%s went dead during handshake", client_get_name(client_p, MASK_IP));
     return;
   }
 
@@ -870,10 +816,10 @@ serv_connect_callback(fde_t *fd, int status, void *data)
     /* We have an error, so report it and quit */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Error connecting to %s: %s",
-                         get_client_name(client_p, SHOW_IP), comm_errstr(status));
+                         client_get_name(client_p, SHOW_IP), comm_errstr(status));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Error connecting to %s: %s",
-                         get_client_name(client_p, MASK_IP), comm_errstr(status));
+                         client_get_name(client_p, MASK_IP), comm_errstr(status));
 
     /*
      * If a fd goes bad, call dead_link() the socket is no
@@ -890,9 +836,9 @@ serv_connect_callback(fde_t *fd, int status, void *data)
   if (!conf)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-                         "Lost connect{} block for %s", get_client_name(client_p, SHOW_IP));
+                         "Lost connect{} block for %s", client_get_name(client_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-                         "Lost connect{} block for %s", get_client_name(client_p, MASK_IP));
+                         "Lost connect{} block for %s", client_get_name(client_p, MASK_IP));
 
     exit_client(client_p, "Lost connect{} block");
     return;
@@ -921,9 +867,9 @@ serv_connect_callback(fde_t *fd, int status, void *data)
   if (IsDead(client_p))
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-                         "%s went dead during handshake", get_client_name(client_p, SHOW_IP));
+                         "%s went dead during handshake", client_get_name(client_p, SHOW_IP));
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-                         "%s went dead during handshake", get_client_name(client_p, MASK_IP));
+                         "%s went dead during handshake", client_get_name(client_p, MASK_IP));
     return;
   }
 
