@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2016 ircd-hybrid development team
+ *  Copyright (c) 1997-2017 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file user.c
  * \brief User related functions.
- * \version $Id: user.c 7770 2016-10-08 16:30:18Z michael $
+ * \version $Id: user.c 8062 2017-03-23 17:13:05Z michael $
  */
 
 #include "stdinc.h"
@@ -52,7 +52,7 @@
 #include "isupport.h"
 #include "tls.h"
 
-static char umode_buffer[IRCD_BUFSIZE];
+static char umode_buffer[UMODE_MAX_STR];
 
 const struct user_modes *umode_map[256];
 const struct user_modes  umode_tab[] =
@@ -112,10 +112,10 @@ void
 show_lusers(struct Client *client_p)
 {
   if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
-    sendto_one_numeric(client_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
+    sendto_one_numeric(client_p, &me, RPL_LUSERCLIENT, (dlink_list_length(&global_client_list) - Count.invisi),
                        Count.invisi, dlink_list_length(&global_server_list));
   else
-    sendto_one_numeric(client_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
+    sendto_one_numeric(client_p, &me, RPL_LUSERCLIENT, (dlink_list_length(&global_client_list) - Count.invisi),
                        Count.invisi, 1);
 
   if (Count.oper)
@@ -129,26 +129,17 @@ show_lusers(struct Client *client_p)
 
   if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
   {
-    sendto_one_numeric(client_p, &me, RPL_LUSERME, Count.local, Count.myserver);
-    sendto_one_numeric(client_p, &me, RPL_LOCALUSERS, Count.local, Count.max_loc);
+    sendto_one_numeric(client_p, &me, RPL_LUSERME, dlink_list_length(&local_client_list), dlink_list_length(&local_server_list));
+    sendto_one_numeric(client_p, &me, RPL_LOCALUSERS, dlink_list_length(&local_client_list), Count.max_loc);
+    sendto_one_numeric(client_p, &me, RPL_GLOBALUSERS, dlink_list_length(&global_client_list), Count.max_tot);
+    sendto_one_numeric(client_p, &me, RPL_STATSCONN, Count.max_loc_con, Count.max_loc, Count.totalrestartcount);
   }
   else
   {
-    sendto_one_numeric(client_p, &me, RPL_LUSERME, Count.total, 0);
-    sendto_one_numeric(client_p, &me, RPL_LOCALUSERS, Count.total, Count.max_tot);
+    sendto_one_numeric(client_p, &me, RPL_LUSERME, dlink_list_length(&global_client_list), 0);
+    sendto_one_numeric(client_p, &me, RPL_LOCALUSERS, dlink_list_length(&global_client_list), Count.max_tot);
+    sendto_one_numeric(client_p, &me, RPL_GLOBALUSERS, dlink_list_length(&global_client_list), Count.max_tot);
   }
-
-  sendto_one_numeric(client_p, &me, RPL_GLOBALUSERS, Count.total, Count.max_tot);
-
-  if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
-    sendto_one_numeric(client_p, &me, RPL_STATSCONN, Count.max_loc_con,
-                       Count.max_loc_cli, Count.totalrestartcount);
-
-  if (Count.local > Count.max_loc_cli)
-    Count.max_loc_cli = Count.local;
-
-  if ((Count.local + Count.myserver) > Count.max_loc_con)
-    Count.max_loc_con = Count.local + Count.myserver;
 }
 
 /* report_and_set_user_flags()
@@ -210,16 +201,16 @@ report_and_set_user_flags(struct Client *client_p, const struct MaskItem *conf)
 static void
 introduce_client(struct Client *client_p)
 {
-  dlink_node *node = NULL;
-  char ubuf[IRCD_BUFSIZE] = "";
+  dlink_node *node;
+  char buf[UMODE_MAX_STR] = "";
 
-  send_umode(client_p, MyConnect(client_p), 0, ubuf);
+  send_umode(client_p, MyConnect(client_p), 0, buf);
   watch_check_hash(client_p, RPL_LOGON);
 
-  if (ubuf[0] == '\0')
+  if (buf[0] == '\0')
   {
-    ubuf[0] = '+';
-    ubuf[1] = '\0';
+    buf[0] = '+';
+    buf[1] = '\0';
   }
 
   DLINK_FOREACH(node, local_server_list.head)
@@ -233,7 +224,7 @@ introduce_client(struct Client *client_p)
                client_p->servptr->id,
                client_p->name, client_p->hopcount+1,
                client_p->tsinfo,
-               ubuf, client_p->username, client_p->host,
+               buf, client_p->username, client_p->host,
                client_p->sockhost, client_p->id,
                client_p->account,
                client_p->info);
@@ -292,7 +283,7 @@ check_xline(struct Client *client_p)
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "X-line Rejecting [%s] [%s], user %s [%s]",
                          client_p->info, gecos->reason,
-                         get_client_name(client_p, HIDE_IP),
+                         client_get_name(client_p, HIDE_IP),
                          client_p->sockhost);
 
     ++ServerStats.is_ref;
@@ -411,8 +402,8 @@ register_local_user(struct Client *client_p)
    * probably be just a percentage of the MAXCLIENTS...
    *   -Taner
    */
-  if ((Count.local >= GlobalSetOptions.maxclients + MAX_BUFFER) ||
-      (Count.local >= GlobalSetOptions.maxclients && !HasFlag(client_p, FLAGS_NOLIMIT)))
+  if ((dlink_list_length(&local_client_list) >= GlobalSetOptions.maxclients + MAX_BUFFER) ||
+      (dlink_list_length(&local_client_list) >= GlobalSetOptions.maxclients && !HasFlag(client_p, FLAGS_NOLIMIT)))
   {
     sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
                          "Too many clients, rejecting %s[%s].",
@@ -458,20 +449,6 @@ register_local_user(struct Client *client_p)
     ++Count.invisi;
   }
 
-  if (++Count.local > Count.max_loc)
-  {
-    Count.max_loc = Count.local;
-
-    if (!(Count.max_loc % 10))
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                           "New maximum local client connections: %u",
-                           Count.max_loc);
-  }
-
-  if (++Count.total > Count.max_tot)
-    Count.max_tot = Count.total;
-  ++Count.totalrestartcount;
-
   assert(client_p->servptr == &me);
   SetClient(client_p);
   dlinkAdd(client_p, &client_p->lnode, &client_p->servptr->serv->client_list);
@@ -482,6 +459,25 @@ register_local_user(struct Client *client_p)
   dlink_move_node(&client_p->connection->lclient_node,
                   &unknown_list, &local_client_list);
 
+  if (dlink_list_length(&local_client_list) > Count.max_loc)
+  {
+    Count.max_loc = dlink_list_length(&local_client_list);
+
+    if (!(Count.max_loc % 10))
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                           "New maximum local client connections: %u",
+                           Count.max_loc);
+  }
+
+  if ((dlink_list_length(&local_client_list) +
+       dlink_list_length(&local_server_list)) > Count.max_loc_con)
+    Count.max_loc_con = dlink_list_length(&local_client_list) +
+                        dlink_list_length(&local_server_list);
+
+  if (dlink_list_length(&global_client_list) > Count.max_tot)
+    Count.max_tot = dlink_list_length(&global_client_list);
+  ++Count.totalrestartcount;
+
   user_welcome(client_p);
   userhost_add(client_p->sockhost, 0);
   AddFlag(client_p, FLAGS_USERHOST);
@@ -511,12 +507,13 @@ register_remote_user(struct Client *client_p)
   if (HasFlag(client_p->servptr, FLAGS_SERVICE))
     AddFlag(client_p, FLAGS_SERVICE);
 
-  if (++Count.total > Count.max_tot)
-    Count.max_tot = Count.total;
-
   SetClient(client_p);
   dlinkAdd(client_p, &client_p->lnode, &client_p->servptr->serv->client_list);
   dlinkAdd(client_p, &client_p->node, &global_client_list);
+
+  if (dlink_list_length(&global_client_list) > Count.max_tot)
+    Count.max_tot = dlink_list_length(&global_client_list);
+
   userhost_add(client_p->sockhost, 1);
   AddFlag(client_p, FLAGS_USERHOST);
 
@@ -699,7 +696,7 @@ send_umode(struct Client *client_p, unsigned int dispatch,
 void
 send_umode_out(struct Client *client_p, unsigned int old)
 {
-  char buf[IRCD_BUFSIZE] = "";
+  char buf[UMODE_MAX_STR] = "";
 
   send_umode(client_p, MyConnect(client_p), old, buf);
 
@@ -711,7 +708,7 @@ send_umode_out(struct Client *client_p, unsigned int old)
 void
 user_set_hostmask(struct Client *client_p, const char *hostname, const int what)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   if (!strcmp(client_p->host, hostname))
     return;
